Class: Studium::Afterburn

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/exams/afterburn.rb

Overview

Studium::Afterburn

Constant Summary collapse

NAMESPACE =
#

NAMESPACE

#
inspect
FILE_MAIN_TOPIC_AT_ROEBE_HOME =
#

FILE_MAIN_TOPIC_AT_ROEBE_HOME

#
RUBY_STUDIUM_HOME_DIR+'yaml/main_topic.yml'

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(commandline_arguments = nil, run_already = true) ⇒ Afterburn

#

initialize

#


48
49
50
51
52
53
54
55
56
57
# File 'lib/studium/exams/afterburn.rb', line 48

def initialize(
    commandline_arguments = nil,
    run_already           = true
  )
  reset
  set_commandline_arguments(
    commandline_arguments
  )
  run if run_already
end

Class Method Details

.[](i = '') ⇒ Object

#

Studium::Afterburn[]

#


256
257
258
# File 'lib/studium/exams/afterburn.rb', line 256

def self.[](i = '')
  new(i)
end

Instance Method Details

#add_this_entry(i) ⇒ Object

#

add_this_entry (add tag)

This method can be used to add a new entry to the list of afterburn exams.

Note that the method will prepend to the dataset, when a new entry is added. The reason for this behaviour is quite simple: if a user invokes this class via the –add flag, then the user most likely wanted to make the exam topic that he/she has added as the most important exam right now. In other words, the exam that the user wants to train for specifically.

Invocation example:

aburn --add syszoo
#


97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/studium/exams/afterburn.rb', line 97

def add_this_entry(i)
  if i.is_a? Array
    i = i.join(' ').strip
  end
  _ = FILE_MAIN_TOPIC
  if File.exist? _
    dataset = YAML.load_file(_)
    case i
    when /^-?-?add (.+)$/i
      this_topic = $1.to_s.dup
      if dataset.include? this_topic
        opnn; e 'The topic '+sfancy(this_topic)+' is already included.'
      else
        opnn; e 'Adding the topic '+sfancy(this_topic)+' next.'
        dataset.prepend(this_topic)
        what = YAML.dump(dataset)
        into = FILE_MAIN_TOPIC
        opnn; e 'Storing into `'+sfile(into)+'`.'
        write_what_into(what, into)
        if is_on_roebe?
          into = FILE_MAIN_TOPIC_AT_ROEBE_HOME
          opnn; e 'Storing into `'+sfile(into)+'`.'
          write_what_into(what, into)
        end
      end
    end
  else
    opnn; no_file_exists_at(_) 
  end
end

#determine_the_main_topic_in_useObject

#

determine_the_main_topic_in_use

#


187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/studium/exams/afterburn.rb', line 187

def determine_the_main_topic_in_use
  _ = @dataset_containing_all_topics
  if _.is_a? Array
    if @select_only_this_number
      target_number = @select_only_this_number.to_i
      if @select_only_this_number.start_with? '-'
        _ = _.reverse[target_number - 1]
      else
        if target_number > _.size
          target_number = _.size
        end
        _ = _[target_number - 1]
      end
    else
      _ = _.first
    end
  end
  @main_topic = _ # Assign to @main_topic here.
end
#

menu (menu tag)

#


131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/studium/exams/afterburn.rb', line 131

def menu(
    i = @commandline_arguments
  )
  if i.is_a? Array
    i.each {|entry| menu(entry) }
  else
    case i # case tag
    # ===================================================================== #
    # === aburn --add syszoo
    # ===================================================================== #
    when /^-?-?add$/i
      add_this_entry(@commandline_arguments)
      exit_program
    # ===================================================================== #
    # === aburn --overview
    # ===================================================================== #
    when /^-?-?overview$/i
      _ = FILE_MAIN_TOPIC
      if File.exist? _
        e
        YAML.load_file(_).each {|line|
          e "  #{royalblue(line)}"
        }
        e
      else
        no_file_exists_at(_)
      end
      exit
    # ===================================================================== #
    # === aburn --open
    # ===================================================================== #
    when /^-?-?open$/
      _ = RUBY_STUDIUM_HOME_DIR+'exams/afterburn.rb'
      open_in_editor(_)
      open_in_editor(FILE_MAIN_TOPIC_AT_ROEBE_HOME) if is_on_roebe?
      exit
    # ===================================================================== #
    # === aburn --help
    # ===================================================================== #
    when /^-?-?help/
      show_help
      exit
    else
      if i =~ /^(-?\d+)$/
        # ================================================================= #
        # In this case we will delect a number from the dataset.
        # ================================================================= #
        select_only_this_number($1.to_s.dup)
      end
    end
  end
end

#resetObject

#

reset (reset tag)

#


62
63
64
65
66
67
68
69
# File 'lib/studium/exams/afterburn.rb', line 62

def reset
  super()
  # ======================================================================= #
  # === @namespace
  # ======================================================================= #
  @namespace = NAMESPACE
  reset_instance_variables
end

#reset_instance_variablesObject

#

reset_instance_variables

#


74
75
76
77
# File 'lib/studium/exams/afterburn.rb', line 74

def reset_instance_variables
  @dataset_containing_all_topics = ::Studium.main_topic?(:return_the_full_dataset) # Grab the main topic here.
  @select_only_this_number = nil
end

#runObject

#

run (run tag)

#


247
248
249
250
251
# File 'lib/studium/exams/afterburn.rb', line 247

def run
  menu
  determine_the_main_topic_in_use
  Studium.ask_exam_question(use_this_topic: @main_topic)
end

#select_only_this_number(i) ⇒ Object

#

select_only_this_number

#


210
211
212
# File 'lib/studium/exams/afterburn.rb', line 210

def select_only_this_number(i)
  @select_only_this_number = i
end

#show_helpObject

#

show_help (help tag)

To invoke this method, try:

afterburn --help
#


222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/studium/exams/afterburn.rb', line 222

def show_help
  e
  e 'You can pass in a number to this class, to select a specific'
  e 'theme. This should ideally be a negative number '\
    'such as '+royalblue('-1')
  e
  e gold('Example:')
  e
  e cadetblue('  afterburn -1')
  e
  e 'For an overview over the available afterburn-topics, use this option:'
  e
  e royalblue('  afterburn --overview')
  e
  e 'Last but not least, these are the available options:'
  e
  e '  --open      # open the file where the afterburn-exam topics are stored'
  e '  --overview  # show which topics are registered currently'
  e '  --add       # add a particular topic'
  e
end