Class: Studium::AudioStats

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/utility_scripts/audio_stats.rb

Overview

Studium::AudioStats

Constant Summary collapse

NAMESPACE =
#

NAMESPACE

#
inspect
ALSO_REPORT_THE_TOTAL_FILE_SIZE =
#

ALSO_REPORT_THE_TOTAL_FILE_SIZE

#
true

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(run_already = true) ⇒ AudioStats

#

initialize

#


31
32
33
34
# File 'lib/studium/utility_scripts/audio_stats.rb', line 31

def initialize(run_already = true)
  reset
  run if run_already
end

Instance Method Details

#analyse_the_resultsObject

#

analyse_the_results

The output will be fairly verbose.

#


109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/studium/utility_scripts/audio_stats.rb', line 109

def analyse_the_results
  if have_we_found_audio_files?
    _ = audio_files? # Use a pointer here.
    e
    e 'There are '+sfancy(_.size.to_s)+' audio files in total in '\
      'the directory `'+sdir(main_dir?)+'`.'
    @directories_that_contain_audio_files = _.map {|entry| File.dirname(entry) }.uniq
    e
    e 'These audio files can be found in the following '+
      simp(@directories_that_contain_audio_files.size.to_s)+' main directories:'
    e
    @directories_that_contain_audio_files.each_with_index {|this_directory, counter|
      counter += 1
      e ' '+lawngreen(counter.to_s.rjust(4)+')')+' '+
        sdir(this_directory+'/') # .sub(/\/audio$/,'') # <- If we wish to get rid of the "audio/" component.
    }; e
  else
    e 'We could not find any audio files within the '\
      'directory `'+sdir(main_dir?)+'`.'
  end
end

#audio_files?Boolean Also known as: array_audio_files?

#

audio_files?

#

Returns:

  • (Boolean)


76
77
78
# File 'lib/studium/utility_scripts/audio_stats.rb', line 76

def audio_files?
  @array_audio_files
end

#consider_showing_the_total_file_sizeObject

#

consider_showing_the_total_file_size

This method will return the total filesize of the audio files.

#


136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/studium/utility_scripts/audio_stats.rb', line 136

def consider_showing_the_total_file_size
  if ALSO_REPORT_THE_TOTAL_FILE_SIZE and
    !@directories_that_contain_audio_files.empty?
    total_file_size = 0
    _ = array_audio_files?
    _.each {|entry|
      total_file_size += File.size(entry)
    }
    kbytes = ((total_file_size.to_f / 1024.0).to_f).round(3)
    mbytes = ((kbytes / 1024.0)).round(3)
    gbytes = ((mbytes / 1024.0)).round(3)
    opnn; e 'The total file size of all '+orange(_.size.to_s)+' audio files in the '\
            'studium directory is'
    opnn; e sfancy(total_file_size.to_s)+' bytes. '\
            '('+sfancy(gbytes.to_s)+' GB)'
  end
end

#dir?Boolean Also known as: main_dir?

#

dir?

#

Returns:

  • (Boolean)


54
55
56
# File 'lib/studium/utility_scripts/audio_stats.rb', line 54

def dir?
  ROEBE_STUDIUM_DIR
end

#have_we_found_audio_files?Boolean

#

have_we_found_audio_files?

Determine whether we have found any audio files.

#

Returns:

  • (Boolean)


100
101
102
# File 'lib/studium/utility_scripts/audio_stats.rb', line 100

def have_we_found_audio_files?
  !audio_files?.empty?
end

#is_audio_file?(i) ⇒ Boolean Also known as: audio_file?

#

is_audio_file?

#

Returns:

  • (Boolean)


83
84
85
86
87
88
89
90
91
92
93
# File 'lib/studium/utility_scripts/audio_stats.rb', line 83

def is_audio_file?(i)
  array_registered_audio_files = %w( ogg mp3 wma )
  extension_name = File.extname(i)
  begin
    extension_name.delete!('.')
  rescue ArgumentError => error
    e 'The file '+sfile(i)+' was faulty. Encoding issue, it appears to.'
    pp error
  end
  array_registered_audio_files.include? extension_name
end

#obtain_all_audio_filesObject

#

obtain_all_audio_files

This method will obtain all audio files within the studium directory.

#


63
64
65
66
67
68
69
70
71
# File 'lib/studium/utility_scripts/audio_stats.rb', line 63

def obtain_all_audio_files
  @array_audio_files = Dir["#{dir?}**/**"]
  # ======================================================================= #
  # Next, select only audio files.
  # ======================================================================= #
  @array_audio_files.select! {|entry|
    is_audio_file?(entry)
  }
end

#resetObject

#

reset

#


39
40
41
42
43
44
45
46
47
48
49
# File 'lib/studium/utility_scripts/audio_stats.rb', line 39

def reset
  super()
  # ======================================================================= #
  # === @namespace
  # ======================================================================= #
  @namespace = NAMESPACE
  # ======================================================================= #
  # === @directories_that_contain_audio_files
  # ======================================================================= #
  @directories_that_contain_audio_files = nil # Nil initially.
end

#runObject

#

run

#


157
158
159
160
161
# File 'lib/studium/utility_scripts/audio_stats.rb', line 157

def run
  obtain_all_audio_files
  analyse_the_results
  consider_showing_the_total_file_size
end