Class: Studium::BOKU::ThreePillars

Inherits:
Studium::Base show all
Defined in:
lib/studium/universities_in_austria/boku/three_pillars.rb

Overview

Studium::BOKU::ThreePillars

Constant Summary

Constants inherited from Studium::Base

Studium::Base::ARRAY_HTML_COLOURS_IN_USE, Studium::Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Studium::Base::COLOURS, Studium::Base::COMMON_YEAR_DAYS_IN_MONTH, Studium::Base::GRAY, Studium::Base::LEFT_PADDING, Studium::Base::NAMESPACE, Studium::Base::N_CHARACTERS_PER_LINE, Studium::Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Studium::Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(commandline_arguments = nil, run_already = true) ⇒ ThreePillars

#

initialize

#


33
34
35
36
37
38
39
40
41
42
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 33

def initialize(
    commandline_arguments = nil,
    run_already           = true
  )
  reset
  set_commandline_arguments(
    commandline_arguments
  )
  run if run_already
end

Instance Attribute Details

#n_ects_pillar_engineeringObject (readonly)

Returns the value of attribute n_ects_pillar_engineering.



26
27
28
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 26

def n_ects_pillar_engineering
  @n_ects_pillar_engineering
end

#n_ects_pillar_scienceObject (readonly)

Returns the value of attribute n_ects_pillar_science.



27
28
29
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 27

def n_ects_pillar_science
  @n_ects_pillar_science
end

#n_ects_pillar_socialObject (readonly)

Returns the value of attribute n_ects_pillar_social.



28
29
30
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 28

def n_ects_pillar_social
  @n_ects_pillar_social
end

Class Method Details

.[](i = '') ⇒ Object

#

Studium::BOKU::ThreePillars[]

#


224
225
226
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 224

def self.[](i = '')
  new(i)
end

Instance Method Details

#determine_which_curriculum_to_useObject

#

determine_which_curriculum_to_use

#


103
104
105
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 103

def determine_which_curriculum_to_use
  @use_this_curriculum = :dummy
end

#iterate_through_the_registered_lecturesObject

#

iterate_through_the_registered_lectures

#


129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 129

def iterate_through_the_registered_lectures
  @n_ects_pillar_engineering = 0
  @n_ects_pillar_science     = 0
  @n_ects_pillar_social      = 0
  @dataset.each {|entry|
    entry.squeeze!(' ')
    pointer = @dataset_containing_all_lectures[entry]
    e "Nil value for #{sfancy(entry)}" if pointer.nil?
    boku_three_pillars = pointer[:boku_three_pillars]
    n_ects_points      = pointer[:ects]
    if boku_three_pillars.nil?
      e orangered(
          'Missing entry (no boku-pillar entry) for `'
        )+
        sfile(entry)+
        orangered('`.')
    else
      splitted = boku_three_pillars.split('/').map(&:to_f)
      use_this_proportion1 = (n_ects_points * splitted[0]) / 100.0
      @n_ects_pillar_engineering += use_this_proportion1
      use_this_proportion2 = (n_ects_points * splitted[1]) / 100.0
      @n_ects_pillar_science     += use_this_proportion2
      use_this_proportion3 = (n_ects_points * splitted[2]) / 100.0
      @n_ects_pillar_social      += use_this_proportion3
      if splitted.sum == 100.0
        # All is fine in this event.
      else
        e orangered('Something is wrong for ')+sfancy(entry)
        e orangered('The BOKU 3 pillars attribution is not at 100%.')
        exit
      end
      if @show_every_attributed_lecture
        e "#{entry} (#{steelblue(boku_three_pillars.to_s)})"
      end
    end
  }
  report_our_findings
end
#

menu (menu tag)

#


79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 79

def menu(
    i = @commandline_arguments
  )
  if i.is_a? Array
    i.each {|entry| menu(entry) }
  else
    case i # case tag
    # ===================================================================== #
    # === help
    # ===================================================================== #
    when /^-?-?help$/i
      show_help
      exit
    else
      if i
        @use_this_curriculum = i.to_s.delete('-').to_sym
      end
    end
  end
end

#name_of_the_curriculum?Boolean

#

name_of_the_curriculum?

#

Returns:

  • (Boolean)


122
123
124
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 122

def name_of_the_curriculum?
  @use_this_curriculum
end

#read_in_dataset_from_the_curriculum_file(i = @use_this_curriculum) ⇒ Object

#

read_in_dataset_from_the_curriculum_file

This method will read in the dataset from the curriculum-file that we wish to use.

#


113
114
115
116
117
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 113

def read_in_dataset_from_the_curriculum_file(
    i = @use_this_curriculum
  )
  @dataset = read_dataset_from_a_curriculum_file(i)
end

#report_our_findingsObject Also known as: report

#

report_our_findings

This method will report the amount of ECTS points attributed to “Technik”, “NaWi” and “SoWiRe” - the three pillars at the BOKU.

#


174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 174

def report_our_findings
  e "#{rev}Total amount of ECTS in the three pillars in the "\
    "curriculum #{steelblue(name_of_the_curriculum?)}:"
  e
  total_ects_points = 0
  rounded_value = @n_ects_pillar_engineering.round(2)
  total_ects_points += rounded_value
  padded_and_rounded_value = '%.2f' % rounded_value.to_f
  n_rjust = 6
  # ======================================================================= #
  # === Technik-Säule
  # ======================================================================= #
  e mediumseagreen("  Technik-Säule (Technik, Ingenieurwissenschaften):               ")+
    steelblue(padded_and_rounded_value.rjust(n_rjust))
  rounded_value = @n_ects_pillar_science.round(2)
  total_ects_points += rounded_value
  padded_and_rounded_value = '%.2f' % rounded_value.to_f
  # ======================================================================= #
  # === NaWi-Säule
  # ======================================================================= #
  e mediumseagreen("  NaWi-Säule    (Naturwissenschaften):                            ")+
    steelblue(padded_and_rounded_value.rjust(n_rjust))
  rounded_value = @n_ects_pillar_social.round(2)
  total_ects_points += rounded_value
  padded_and_rounded_value = '%.2f' % rounded_value.to_f
  # ======================================================================= #
  # === Sozial-Säule
  # ======================================================================= #
  e mediumseagreen("  Sozial-Säule  (Wirtschafts-, Sozial- und Rechtswissenschaften): ")+
    steelblue(padded_and_rounded_value.rjust(n_rjust))
  e
  e 'Calculated total ECTS points: '+
    steelblue(
      total_ects_points.to_s.to_f.round(1)
    )
end

#resetObject

#

reset (reset tag)

#


47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 47

def reset
  super()
  # ======================================================================= #
  # === @dataset_containing_all_lectures
  # ======================================================================= #
  @dataset_containing_all_lectures = return_dataset_from_the_file_lecture_information
  # ======================================================================= #
  # === @show_every_attributed_lecture
  #
  # If this variable is set to true then each lecture will be displayed
  # on the commandline as well.
  # ======================================================================= #
  @show_every_attributed_lecture = false
end

#runObject

#

run (run tag)

#


214
215
216
217
218
219
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 214

def run
  determine_which_curriculum_to_use
  menu
  read_in_dataset_from_the_curriculum_file
  iterate_through_the_registered_lectures
end

#show_helpObject

#

show_help (help tag)

#


65
66
67
68
69
70
71
72
73
74
# File 'lib/studium/universities_in_austria/boku/three_pillars.rb', line 65

def show_help
  e
  e 'Presently, the following options are available:'
  e
  e '  3pillars --aw'
  e '  3pillars --lbt'
  e '  3pillars --bvek'
  e
  e
end