Class: Studium::Calendar

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/utility_scripts/calendar/misc.rb,
lib/studium/utility_scripts/calendar/calendar.rb

Overview

Studium::Calendar

Constant Summary collapse

N_JUST_TO_THE_RIGHT_SIDE =
#

N_JUST_TO_THE_RIGHT_SIDE

#
72

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::NAMESPACE, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Studium::Colours::COLOURS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(commandline_arguments = nil, run_already = true) ⇒ Calendar

#

initialize

#


33
34
35
36
37
38
39
40
41
42
# File 'lib/studium/utility_scripts/calendar/calendar.rb', line 33

def initialize(
    commandline_arguments = nil,
    run_already           = true
  )
  reset
  set_commandline_arguments(
    commandline_arguments
  )
  run if run_already
end

Class Method Details

.[](i = '') ⇒ Object

#

Studium::Calendar[]

#


243
244
245
# File 'lib/studium/utility_scripts/calendar/calendar.rb', line 243

def self.[](i = '')
  new(i)
end

Instance Method Details

#consider_renaming_the_kde_konsoleObject

#

consider_renaming_the_kde_konsole

#


20
21
22
23
24
# File 'lib/studium/utility_scripts/calendar/misc.rb', line 20

def consider_renaming_the_kde_konsole
  if is_on_roebe?
    Roebe.rename_konsole_tab('calendar')
  end
end

#main_dataset?Boolean

#

main_dataset?

#

Returns:

  • (Boolean)


74
75
76
# File 'lib/studium/utility_scripts/calendar/calendar.rb', line 74

def main_dataset?
  @dataset_from_the_file_lecture_information
end
#

menu (menu tag)

#


81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/studium/utility_scripts/calendar/calendar.rb', line 81

def menu(
    i = commandline_arguments?
  )
  if i.is_a? Array
    i.each {|entry| menu(entry) }
  else
    case i # case tag
    # ===================================================================== #
    # === --help
    # ===================================================================== #
    when /help/
      show_help
    end
  end
end

#modify_this_hash_with_upcoming_lva_dates(this_day, lva_dates, this_lecture) ⇒ Object

#

modify_this_hash_with_upcoming_lva_dates

#


227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/studium/utility_scripts/calendar/calendar.rb', line 227

def modify_this_hash_with_upcoming_lva_dates(
    this_day,
    lva_dates,
    this_lecture
  )
  if lva_dates.any? {|entry| entry.include? this_day }
    unless @hash_sorted_by_days.has_key? this_day
      @hash_sorted_by_days[this_day] = []
    end
    @hash_sorted_by_days[this_day] << this_lecture
  end
end

#report(i = @hash_sorted_by_days) ⇒ Object

#

report (report tag)

#


145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/studium/utility_scripts/calendar/calendar.rb', line 145

def report(
    i = @hash_sorted_by_days
  )
  e
  if i.is_a? Hash
    if i.empty?
      e 'No lecture was found in the coming 7 days.'
    else
      sorted_hash = i.sort_by {|date_of_the_lecture, inner_array|
        Time.parse(date_of_the_lecture) # We need it sorted via Time.
      }
      sorted_hash = Hash[sorted_hash]
      sorted_hash.each_pair {|weekday, array_name_of_the_lectures| # weekday is something like: "13.10.2020"
        # ================================================================= #
        # The Array is not yet sorted by time, e. g. 14:00 versus
        # 08:00 o'clock. Thus, we must first sort it based on
        # time.
        # ================================================================= #
        array_name_of_the_lectures = sort_these_lecture_names_by_time(
          array_name_of_the_lectures, weekday
        )
        array_name_of_the_lectures.each {|name_of_the_lecture|
          result = '  '+
                   steelblue(weekday)+' '+
                   seagreen('')+
                   lightgreen(
                     name_of_the_lecture.ljust(N_JUST_TO_THE_RIGHT_SIDE) # Pad it a little here.
                   )
          # =============================================================== #
          # Next, we need to fetch the time on that day, so we
          # know when the course will be held.
          # =============================================================== #
          pointer    = main_dataset?[name_of_the_lecture]
          lva_dates  = pointer['lva_dates']
          priority   = pointer[:priority]
          university = pointer[:university]
          correct_entry = lva_dates.select {|line|
            line.include? weekday
          }
          correct_entry = correct_entry.first if correct_entry.is_a? Array
          result = result.dup if result.frozen?
          extracted_time = extract_the_time_from(correct_entry)
          # =============================================================== #
          # Next, we will replace the n minutes part with unicode
          # variants if we are on a roebe-system.
          # =============================================================== #
          if is_on_roebe?
            # ============================================================= #
            # extracted_time now may look like this: "14:30-17:45"
            # ============================================================= #
            _ = ''.dup
            inner_split = extracted_time.split('-')
            inner_split.each_with_index {|time_entry, index|
              splitted = time_entry.split(':')
              unicode_numbers = replace_regular_numbers_with_unicode_numbers(splitted[-1])
              splitted[-1] = unicode_numbers
              _ << '-' if (index % 2 == 1)
              _ << splitted.join(':')
            }
            extracted_time = _.delete(':')
          end
          colourized_extracted_time = tomato(extracted_time) 
          result << " #{colourized_extracted_time}"
          # =============================================================== #
          # Add the priority next.
          # =============================================================== #
          result << mediumpurple(" [Priority: #{priority}]")
          # =============================================================== #
          # Add the university next.
          # =============================================================== #
          result << mediumorchid(" #{university.center(10)}")
          e result
        }
      }
    end
  end
  e
end

#resetObject

#

reset (reset tag)

#


47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/studium/utility_scripts/calendar/calendar.rb', line 47

def reset
  super()
  # ======================================================================= #
  # === @n_days_into_the_future
  #
  # How many days into the future we will "peek".
  # ======================================================================= #
  @n_days_into_the_future = 14
  # ======================================================================= #
  # === @dataset_from_the_file_lecture_information
  # ======================================================================= #
  @dataset_from_the_file_lecture_information = return_dataset_from_the_file_lecture_information
  # ======================================================================= #
  # === @dataset_from_the_file_participating_in_these_courses
  #
  # We must load the dataset stored in the file
  # "participating_in_these_courses.yml"
  # ======================================================================= #
  @dataset_from_the_file_participating_in_these_courses = 
    @dataset_from_the_file_lecture_information.select {|key, inner_hash|
      inner_hash[:currently_participating_in_this_course] == true
    }
end

#runObject

#

run (run tag)

#


29
30
31
32
33
# File 'lib/studium/utility_scripts/calendar/misc.rb', line 29

def run
  menu
  consider_renaming_the_kde_konsole
  show_the_courses_in_this_week
end

#show_helpObject

#

show_help

#


100
101
102
# File 'lib/studium/utility_scripts/calendar/calendar.rb', line 100

def show_help
  e 'Currently no help-options are documented.'
end

#show_the_courses_in_this_weekObject

#

show_the_courses_in_this_week

This method will show the courses that are coming in this week - or, more accurately, the next 7 days.

#


110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/studium/utility_scripts/calendar/calendar.rb', line 110

def show_the_courses_in_this_week
  _ = @dataset_from_the_file_lecture_information
  today = Time.now
  day1 = dd_mm_yyyy(today)
  @hash_sorted_by_days = {}
  @hash_sorted_by_days.default = []
  @dataset_from_the_file_participating_in_these_courses.each {|this_lecture|
    if _.has_key? this_lecture
      pointer = _[this_lecture]
    else
      e 'No key found called '+steelblue(this_lecture.to_s)
      exit
    end
    lva_dates = pointer['lva_dates']
    if lva_dates
      0.upto(@n_days_into_the_future).each {|day_number_n|
        modify_this_hash_with_upcoming_lva_dates(
          dd_mm_yyyy(
            # ============================================================= #
            # We refer to day1 as our starting-day:
            # ============================================================= #
            Time.parse(day1) + (ONE_DAY * day_number_n)
          ),
          lva_dates,
          this_lecture
        )
      }
    end
  }
  report(@hash_sorted_by_days)
end