Class: Studium::Curricula::Mitteilungsblätter

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/curricula/mitteilungsblätter.rb

Overview

Studium::Curricula::Mitteilungsblätter

Constant Summary collapse

NAMESPACE =
#

NAMESPACE

#
inspect
FILE_MITTEILUNGSBLÄTTER =
#

FILE_MITTEILUNGSBLÄTTER

bl $RSRC/studium/lib/studium/yaml/mitteilungsblätter.yml
#
"#{Studium.project_yaml_directory?}mitteilungsblätter.yml"

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Studium::Colours

Studium::Colours::COLOURS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Studium::Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(commandline_arguments = nil, run_already = true) ⇒ Mitteilungsblätter

#

initialize

#


41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 41

def initialize(
    commandline_arguments = nil,
    run_already           = true
  )
  reset
  if commandline_arguments and commandline_arguments.empty?
    show_all_mitteilungsblätter
  else
    set_commandline_arguments(
      commandline_arguments
    )
    run if run_already
  end
end

Class Method Details

.[](i = '') ⇒ Object

#

Studium::Curricula::Mitteilungsblätter[]

#


328
329
330
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 328

def self.[](i = '')
  new(i)
end

Instance Method Details

#handle_this_curriculum(i) ⇒ Object

#

handle_this_curriculum

To enter this method, try:

mblatt --indi3
mblatt --indi4
#


292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 292

def handle_this_curriculum(i)
  i = i.dup if i.frozen?
  if i.start_with? '--'
    i.sub!(/^--/,'')
  end
  lectures_from_the_curriculum = return_this_curriculum(i)
  # Next we must obtain all "Mitteilungsblätter".
  _ = lectures_from_the_curriculum.map {|key, inner_hash|
    inner_hash['curricula']
  }
  _.flatten!
  _.uniq!
  if i.include?('indi3') or i.include?('indi2')
    # ===================================================================== #
    # Reject master-curricula from the list, and entries that
    # are too short.
    # ===================================================================== #
    _.reject! {|entry| entry.start_with?('066') or (entry.size == 3) }
  end
  _.sort!
  e
  show_the_mitteilungsblatt_for_this_curriculum(_)
  e
end

#load_the_yaml_datasetObject

#

load_the_yaml_dataset

#


92
93
94
95
96
97
98
99
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 92

def load_the_yaml_dataset
  _ = Studium.file_mitteilungsblätter
  if File.exist? _
    @dataset = YAML.load_file(_)
  else
    opnn; no_file_exists_at(_)
  end
end
#

menu (menu tag)

Pass the commandline arguments into the menu() interface.

#


142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 142

def menu(
    i = @commandline_arguments
  )
  if i.is_a? Array
    i.each {|entry| menu(entry) }
  else
    if i.start_with? '--'
      # ===================================================================== #
      # Leading '--' commands will be treated differently in that we will
      # assume that this will be something like --indi3. This means that
      # we will obtain all lectures, then obtain all individual curricula,
      # and then display these curricula.
      # ===================================================================== #
      handle_this_curriculum(i)
    else
      # ===================================================================== #
      # Define three important variables next.
      # ===================================================================== #
      this_university = from_curriculum_id_to_university(i)
      name_of_the_curriculum = return_name_of_the_curriculum_based_on_this_curriculum_id(i)
      url_to_the_remote_mitteilungsblatt = @dataset[i]
      if url_to_the_remote_mitteilungsblatt.is_a? Array
        if url_to_the_remote_mitteilungsblatt.size == 1
          url_to_the_remote_mitteilungsblatt = url_to_the_remote_mitteilungsblatt.first
        end
      end
      e steelblue(i)+': '+
          royalblue(
            name_of_the_curriculum.
          ljust(60)
          )+
          mediumpurple(
            " (#{this_university})"
          )
      if @dataset.has_key? i
        if url_to_the_remote_mitteilungsblatt.is_a? Hash
          url_to_the_remote_mitteilungsblatt.each_pair {|key, value|
            if use_german?
              e "  #{lightgreen('')} #{lightgreen(value)} "\
                "(#{royalblue(key)})"
            else
              e "  #{lightgreen('')} #{lightgreen(value)} "\
                "(from #{royalblue(key)})"
            end
          }
        else
          e lightgreen("#{url_to_the_remote_mitteilungsblatt}")
        end
      else
        if use_german?
          e crimson('  Nicht registrierter URL Eintrag: ')+
            steelblue(i)
        else
          e crimson('  Not registered URL entry: ')+
            steelblue(i)
        end
      end
    end
  end
end

#process_commandline_argumentsObject

#

process_commandline_arguments

#


104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 104

def process_commandline_arguments
  @commandline_arguments.map! {|entry|
    if entry.is_a?(String) and
       entry.include?('Bachelorcurriculum') and
       entry.include?(N) and
       entry.include?('(') and
       entry.include?(')')
      # =================================================================== #
      # Here we will seek all entries that are like this: (033282)
      # =================================================================== #
      splitted = entry.split(N)
      entry = splitted.map {|inner_entry| inner_entry.scan(/\(\d{3,6}\)/) }
    end
    entry
  }
  @commandline_arguments.flatten!
  @commandline_arguments.map! {|entry| entry.delete('()') }
  sort_the_commandline_arguments
  # ======================================================================= #
  # Next pass them through the menu() interface.
  # ======================================================================= #
  menu(
    @commandline_arguments
  )
end

#resetObject

#

reset (reset tag)

#


59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 59

def reset
  super()
  # ======================================================================= #
  # === @namespace
  # ======================================================================= #
  @namespace = NAMESPACE
  # ======================================================================= #
  # === @dataset
  #
  # This variable will contain the different "Mitteilungsblätter",
  # or rather, the respective URL to them.
  # ======================================================================= #
  @dataset = nil
  # ======================================================================= #
  # === @use_this_language_for_the_class
  #
  # The following can be either :german or :english. If it is :english
  # then the class will display information in english; otherwise it
  # will display that information in german.
  # ======================================================================= # 
  @use_this_language_for_the_class = :german
end

#right_arrowObject

#

right_arrow

#


225
226
227
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 225

def right_arrow
  ''
end

#runObject

#

run (run tag)

#


320
321
322
323
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 320

def run
  load_the_yaml_dataset
  process_commandline_arguments
end

#show_all_mitteilungsblätterObject

#

show_all_mitteilungsblätter

#


206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 206

def show_all_mitteilungsblätter
  if @dataset.nil?
    load_the_yaml_dataset
  end
  e 'Showing all available Mitteilungsblätter:'
  e
  @dataset.each_pair {|curriculum_id, value|
    value = value.values.first if value.respond_to? :values
    name_of_the_curriculum = turn_id_to_curriculum_name(curriculum_id)
    e "  #{lightblue(name_of_the_curriculum.ljust(30))} "\
      "(#{steelblue(curriculum_id)}):"
    e "    #{olivedrab('')} #{royalblue(value)}"
  }
  e
end

#show_the_mitteilungsblatt_for_this_curriculum(i) ⇒ Object

#

show_the_mitteilungsblatt_for_this_curriculum

Do note that the input to this method is assumed to be an Array, with entries such as [“066220”, “066417”, “066418”, and so forth.

#


235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 235

def show_the_mitteilungsblatt_for_this_curriculum(i)
  if i.is_a? Array
    i.each {|entry|
      show_the_mitteilungsblatt_for_this_curriculum(entry)
    }
  else
    # ===================================================================== #
    # Ok - here we know that we can actually show the "Mitteilungsblatt".
    # ===================================================================== #
    pointer = @dataset[i]
    name_of_the_curriculum = return_name_of_the_curriculum(i)
    this_university        = from_curriculum_id_to_university(i)
    e steelblue(i)+': '+
      royalblue(
        name_of_the_curriculum.ljust(60)
      )+
      mediumpurple(
        " (#{this_university})"
      )
    if pointer
      left_side = pointer.keys.first.to_s
      e lightgreen(left_side)
    end
    # ===================================================================== #
    # Next display all URLs associated with that curriculum. These
    # URLs will have a right arrow, a UNICODE arrow.
    # ===================================================================== #
    if pointer.respond_to? :values
      pointer.values.each {|this_url|
        if this_url.is_a? String
          e "  #{mediumaquamarine(right_arrow)} #{mediumorchid(this_url)}"
        end
      }
    elsif pointer.is_a? Array
      pointer.each {|this_url|
        if this_url.is_a? String
          e "  #{mediumaquamarine(right_arrow)} #{mediumorchid(this_url)}"
        end
      }
    elsif pointer.is_a? String
      e "  #{mediumaquamarine(right_arrow)} #{mediumorchid(pointer)}"
    else
      e 'Not known:'
      pp pointer
    end
  end
end

#sort_the_commandline_argumentsObject

#

sort_the_commandline_arguments

#


133
134
135
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 133

def sort_the_commandline_arguments
  @commandline_arguments.sort_by! {|entry| entry.to_i }
end

#use_german?Boolean

#

use_german?

#

Returns:

  • (Boolean)


85
86
87
# File 'lib/studium/curricula/mitteilungsblätter.rb', line 85

def use_german?
  @use_this_language_for_the_class == :german
end