Class: Studium::Exams::QuestionsSolvedFromDayToDay

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/exams/questions_solved_from_day_to_day.rb

Overview

Studium::Exams::QuestionsSolvedFromDayToDay

Constant Summary collapse

NAMESPACE =
#

NAMESPACE

#
inspect

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(i = nil, run_already = true) ⇒ QuestionsSolvedFromDayToDay

#

initialize

#


34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 34

def initialize(
    i           = nil,
    run_already = true
  )
  reset
  # ======================================================================= #
  # === Handle blocks next
  # ======================================================================= #
  if block_given?
    yielded = yield
    case yielded
    when :be_silent
      be_quiet
    end
  end
  set_commandline_arguments(i)
  run if run_already
end

Class Method Details

.[](i = '') ⇒ Object

#

Studium::Exams::QuestionsSolvedFromDayToDay[]

#


368
369
370
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 368

def self.[](i = '')
  new(i)
end

.return_maximum_amount_of_questions_ever_answeredObject

#

Studium::Exams::QuestionsSolvedFromDayToDay.return_maximum_amount_of_questions_ever_answered

#


359
360
361
362
363
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 359

def self.return_maximum_amount_of_questions_ever_answered
  _ = new { :be_silent }
  _.determine_highest
  _.highest?
end

Instance Method Details

#append_this_line_to_the_main_file(what, into = main_file? ) ⇒ Object

#

append_this_line_to_the_main_file

#


95
96
97
98
99
100
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 95

def append_this_line_to_the_main_file(
    what,
    into = main_file?
  )
  append_what_into(what, into)
end

#dataset?Boolean

#

dataset?

#

Returns:

  • (Boolean)


236
237
238
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 236

def dataset?
  @dataset
end

#determine_highestObject

#

determine_highest

#


115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 115

def determine_highest
  dataset = File.readlines(main_file?)
  # ======================================================================= #
  # The entries will look like:
  #   "06.04.2017: 8060\n",
  # So now we .map and obtain only the part after ': '.
  # ======================================================================= #
  dataset.map! {|line|
    splitted = line.split(': ')
    splitted.last.chomp.to_i
  }
  @highest = dataset.max
end

#highest?Boolean

#

highest?

#

Returns:

  • (Boolean)


132
133
134
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 132

def highest?
  @highest
end

#main_file?Boolean

#

main_file?

#

Returns:

  • (Boolean)


75
76
77
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 75

def main_file?
  FILE_DAILY_QUESTIONS_SOLVED
end
#

menu (menu tag)

#


172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 172

def menu(
    i = commandline_arguments?
  )
  if i.is_a? Array
    i.each {|entry| menu(entry) }
  else
    case i # case tag
    # ===================================================================== #
    # === superstats --update
    # ===================================================================== #
    when /-?-?update/
      update_the_current_options
      exit
    # ===================================================================== #
    # === superstats --highest
    # ===================================================================== #
    when /-?-?highest/,
         /-?-?max$/
      show_highest
      exit
    # ===================================================================== #
    # === superstats --open
    # ===================================================================== #
    when /^-?-?open$/i
      open_the_main_file
      exit
    # ===================================================================== #
    # === superstats --higher
    # ===================================================================== #
    when /-?-?higher/
      modify_dataset(:reject_lower_than_current_entries)
    # ===================================================================== #
    # === superstats --file?
    # ===================================================================== #
    when /-?-?file\??/
      show_the_location_of_the_main_file
      exit
    # ===================================================================== #
    # === superstats --help
    # ===================================================================== #
    when /help/
      show_help; exit
    end
  end
end

#modify_dataset(i = :reject_lower_than_current_entries) ⇒ Object

#

modify_dataset

#


221
222
223
224
225
226
227
228
229
230
231
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 221

def modify_dataset(
    i = :reject_lower_than_current_entries
  )
  case i
  when :reject_lower_than_current_entries
    current_maximum_of_questions_answered = ::Studium::Exams.return_n_questions_solved_in_total
    @dataset.reject! {|key, value|
      value < current_maximum_of_questions_answered
    }
  end
end

#open_the_main_fileObject

#

open_the_main_file

Invoke this method like so:

superstats --open
#


87
88
89
90
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 87

def open_the_main_file
  require 'open' unless Object.const_defined? :Open
  Open.in_editor(main_file?)
end

#report_dataset(i = @dataset) ⇒ Object

#

report_dataset

#


290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 290

def report_dataset(
    i = @dataset
  )
  if be_verbose?
    e 'Calculating the net-differences per day next:'
    e
  end
  day_before_n_questions = nil
  e
  @array_daily_differences.clear
  i.each_pair {|day_month_year, n_questions|
    difference = 0 # Default value.
    if day_before_n_questions
      difference = n_questions - day_before_n_questions
      difference = 0 if difference < 0
      # =================================================================== #
      # Then we can also calculate the difference.
      # =================================================================== #
      # We require Time.parse next.
      # =================================================================== #
      day_before = Time.parse(day_month_year) - 64000
      day_before = (day_before.day.to_s.rjust(2,'0'))+'.'+
                    day_before.month.to_s.rjust(2,'0')+'.'+
                    day_before.year.to_s
      # =================================================================== #
      # Must be important to keep track of how many questions were
      # solved. If 999, then we have 3 entries; if 1000, then we
      # have at the least 4 entries.
      # =================================================================== #
      padding = ' '.dup * (4 - difference.to_s.size)
      @array_daily_differences << difference.to_i
      if @array_daily_differences.empty? or (@array_daily_differences.size < 1)
        n_daily_difference = 0
      else
        n_daily_difference = @array_daily_differences.last.to_i - @array_daily_differences[-2].to_i
      end
      if n_daily_difference > 0
        n_daily_difference = '+'+n_daily_difference.to_s
      end
      formatted_n_daily_difference = mediumpurple(
        n_daily_difference.to_s.rjust(4)
      )
      e '  From day '+
        orange(day_before)+' to day '+
        orange(day_month_year)+
        padding+
        ' +'+crimson(difference.to_s)+
        " (#{formatted_n_daily_difference}) "+
        'questions were answered, '\
        'to a total amount of '+
        slateblue(n_questions.to_s)+'.'
    else # else seed the value.
      day_before_n_questions = n_questions
    end
  }; e
end

#resetObject

#

reset (reset tag)

#


56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 56

def reset
  super()
  # ======================================================================= #
  # === @namespace
  # ======================================================================= #
  @namespace = NAMESPACE
  # ======================================================================= #
  # === @be_verbose
  # ======================================================================= #
  @be_verbose = false
  # ======================================================================= #
  # === @array_daily_differences
  # ======================================================================= #
  @array_daily_differences = []
end

#runObject

#

run (run tag)

#


350
351
352
353
354
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 350

def run
  try_to_load_the_dataset
  menu
  report_dataset
end

#save_this_dataset(dataset) ⇒ Object

#

save_this_dataset

#


243
244
245
246
247
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 243

def save_this_dataset(dataset)
  what = dataset
  into = main_file?
  write_what_into(what, into)
end

#show_helpObject

#

show_help (help tag)

To invoke this method, do:

questionssolvedfromdaytoday --help
#


144
145
146
147
148
149
150
151
152
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 144

def show_help
  e 'The following options are available:'
  e
  e '  --update  # update the current record'
  e '  --open    # open the yaml file'
  e '  --higher  # show which entries are higher than the actual count'
  e '  --highest # show the highest count ever'
  e
end

#show_highestObject

#

show_highest

This method will show the highest entry.

#


107
108
109
110
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 107

def show_highest
  determine_highest
  e "Maximum amount of questions ever answered: #{sfancy(@highest)}."
end

#show_the_location_of_the_main_fileObject

#

show_the_location_of_the_main_file

#


283
284
285
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 283

def show_the_location_of_the_main_file
  e main_file?
end

#try_to_load_the_datasetObject

#

try_to_load_the_dataset

#


157
158
159
160
161
162
163
164
165
166
167
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 157

def try_to_load_the_dataset
  _ = main_file?
  if File.exist? _
    @dataset = YAML.load_file(_)
  else
    if be_verbose?
      opnn; e "No file exists at `#{sfile(_)}`."
    end
    @dataset = nil
  end
end

#update_the_current_options(i = main_file? ) ⇒ Object

#

update_the_current_options (update tag)

To invoke this from the commandline, do:

superstats --update
#


257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/studium/exams/questions_solved_from_day_to_day.rb', line 257

def update_the_current_options(
    i = main_file?
  )
  dataset = File.readlines(i)
  last_entry = dataset.last
  n_answers_available = ::Studium::Exams.n_answers?
  if last_entry.include? today?
    # ===================================================================== #
    # In this case we must update this last entry.
    # ===================================================================== #
    last_entry = "#{today?}: #{n_answers_available}"
    dataset[-1] = last_entry
    save_this_dataset(dataset)
  else
    # ===================================================================== #
    # In that case, we simply append it.
    # ===================================================================== #
    append_this_line_to_the_main_file(
      "#{today?}: #{n_answers_available.to_s}"
    )
  end
end