Class: Studium::Exams::Solved

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/exams/solved/help.rb,
lib/studium/exams/solved/menu.rb,
lib/studium/exams/solved/reset.rb,
lib/studium/exams/solved/solved.rb,
lib/studium/exams/solved/constants.rb,
lib/studium/exams/solved/initialize.rb

Overview

Studium::Exams::Solved

Constant Summary collapse

NAMESPACE =
#

NAMESPACE

#
inspect
PUT_SOLVED_QUESTION_ON_TOP_OF_THE_FILE =
#

PUT_SOLVED_QUESTION_ON_TOP_OF_THE_FILE

If this constant is set to true then we will, upon solving a question, relocate this question to the top of the file.

#
true
SHALL_WE_ALSO_UPDATE_THE_TEN_MAIN_ALIASES =
#

SHALL_WE_ALSO_UPDATE_THE_TEN_MAIN_ALIASES

The following constant is only honoured on “is_roebe?” systems, aka my home system. If true then the ten main aliases will also be updated, in regards to study-related questions (percentage value display).

Currently (28.04.2019) this comes with a slight speed penalty, which is why it has been disabled for the time being. At a later time this may be revisited, though.

#
false

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(commandline_arguments = ARGV, run_already = true, &block) ⇒ Solved

#

initialize

#


18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/studium/exams/solved/initialize.rb', line 18

def initialize(
    commandline_arguments = ARGV,
    run_already           = true,
    &block
  )
  reset
  menu(
    commandline_arguments
  ) if commandline_arguments
  # ======================================================================= #
  # === Handle blocks next
  # ======================================================================= #
  if block_given?
    yielded = yield
    case yielded
    # ===================================================================== #
    # === :be_verbose
    # ===================================================================== #
    when :be_verbose
      set_be_verbose
    # ===================================================================== #
    # === :do_not_run_yet
    # ===================================================================== #
    when :do_not_run_yet
      run_already = false
    end
  end
  case run_already
  # ======================================================================= #
  # === :dont_run_yet
  # ======================================================================= #
  when :dont_run_yet
    run_already = false
  end
  run if run_already
end

Class Method Details

.[]Object

#

Studium::Exams::Solved[]

#


305
306
307
# File 'lib/studium/exams/solved/solved.rb', line 305

def self.[]
  new
end

Instance Method Details

#consider_updating_exam_questions_solved_today(into = FILE_DAILY_QUESTIONS_SOLVED) ⇒ Object

#

consider_updating_exam_questions_solved_today

The purpose of this method is to keep track of how many questions were solved per day. This can then be used by other scripts to compare how many questions were solved from one day to another,

    1. to get some realistic “real” measurement of how many questions

can be solved per day.

In order to achieve this, we will save the minimum number per given day. Or actually, much simpler, to store the first amount of questions solved, obtained on any given time for the FIRST time on THAT day, into a file. In other words, if I woke up and ask a question and manage to solve it, this class here will also keep track of that.

#


77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/studium/exams/solved/solved.rb', line 77

def consider_updating_exam_questions_solved_today(
    into = FILE_DAILY_QUESTIONS_SOLVED # This is a yaml file. We will store into this file.
  )
  # ======================================================================= #
  # Store as a Hash.
  # ======================================================================= #
  today = today?
  hash = {
    today => ::Studium.n_questions_solved_in_total # Obtain how many questions were solved yet.
  }
  if File.exist? into
    dataset = YAML.load_file(into) # This is the existing dataset.
    unless dataset.has_key? today
      dataset.merge!(hash)
      write_what_into(YAML.dump(dataset), into)
    end
    return
  end
  write_what_into(YAML.dump(hash), into) # Else create it anew here.
end

#directory_to_the_exam_topics?Boolean

#

directory_to_the_exam_topics?

#

Returns:

  • (Boolean)


57
58
59
# File 'lib/studium/exams/solved/solved.rb', line 57

def directory_to_the_exam_topics?
  ::Studium.directory_to_the_exam_topics?
end

#invoke_max_stats_classObject

#

invoke_max_stats_class

#


270
271
272
273
# File 'lib/studium/exams/solved/solved.rb', line 270

def invoke_max_stats_class
  require 'studium/statistics/max_stats.rb'
  Studium::Statistics::MaxStats.new { :be_quiet }
end
#

menu (menu tag)

#


14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/studium/exams/solved/menu.rb', line 14

def menu(i)
  if i.is_a? Array
    i.each {|entry| menu(entry) }
  else
    case i # case tag
    # ===================================================================== #
    # === solved --be-verbose
    # ===================================================================== #
    when /^-?-?be(-|_)?verbose?$/i,
         /^-?-?verbose?$/i
      set_be_verbose
    # ===================================================================== #
    # === solved --simulate
    # ===================================================================== #
    when /^-?-?simulate\??$/i
      show_which_question_we_would_mark_as_solved
      exit
    # ===================================================================== #
    # === solved --help
    # ===================================================================== #
    when /^-?-?help$/i
      show_help
      exit
    end
  end
end

#put_solved_question_on_top_of_the_file?Boolean

#

put_solved_question_on_top_of_the_file?

#

Returns:

  • (Boolean)


41
42
43
# File 'lib/studium/exams/solved/solved.rb', line 41

def put_solved_question_on_top_of_the_file?
  @put_solved_question_on_top_of_the_file
end

#resetObject

#

reset (reset tag)

#


16
17
18
19
20
21
22
23
24
25
26
27
28
29
# File 'lib/studium/exams/solved/reset.rb', line 16

def reset
  super()
  # ======================================================================= #
  # === @namespace
  # ======================================================================= #
  @namespace = NAMESPACE
  # ======================================================================= #
  # === @put_solved_question_on_top_of_the_file
  # ======================================================================= #
  @put_solved_question_on_top_of_the_file =
    PUT_SOLVED_QUESTION_ON_TOP_OF_THE_FILE
  set_which_question
  set_be_quiet
end

#return_the_topicObject

#

return_the_topic

#


48
49
50
51
52
# File 'lib/studium/exams/solved/solved.rb', line 48

def return_the_topic
  _ = which_topic?
  _ = ' (Topic: '+simp(_.capitalize.tr('_',' '))+')' unless _.empty?
  return _
end

#runObject

#

run (run tag)

#


298
299
300
# File 'lib/studium/exams/solved/solved.rb', line 298

def run
  run_everything
end

#run_everythingObject

#

run_everything

#


133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/studium/exams/solved/solved.rb', line 133

def run_everything
  # ======================================================================= #
  # First, we need to identify what the line is that we want to find.
  # ======================================================================= #
  line = @which_question.dup.rstrip
  unless line.start_with? '- '
    line.prepend('- ')
  end
  # ======================================================================= #
  # Now we have the line in question. We must determine the target file
  # next. First, the regular one; but also the one on my home system
  # if is_on_roebe? is true.
  # ======================================================================= #
  _ = path_to_exam_topic?+
      Studium.find_corresponding_exam_topic(Studium.last_topic?)
  # ======================================================================= #
  # target_file  = YAML.load_file(_).chomp
  # ======================================================================= #
  target_file    = _
  target_at_home = "#{directory_to_the_exam_topics?}"\
                   "#{File.basename(target_file)}"
  if be_verbose?
    opnn; e 'The target file is at:'
    e
    e "  #{sfile(target_file)}"
    e
  end
  # ======================================================================= #
  # Obtain the line-number next:
  # ======================================================================= #
  line_number    = FindLineInFile.new(
    this_file: target_file,
    this_line: line
  ).line_number?
  if be_verbose?
    opnn; e 'The line number is at: '+sfancy(line_number.to_s)
    opnn; e 'The line to be sought after is exactly this, '\
            'between the ``:'
    e
    e "`#{steelblue(line)}`"
    e
  end
  if line_number # Need to be sure that we have found a number at all.
    # ===================================================================== #
    # Now we have the target file as well as the line number. We can
    # thus modify this file next.
    # ===================================================================== #
    dataset = File.readlines(
      target_file, encoding: main_encoding_to_use?
    )
    old_content = dataset[line_number - 1]
    new_line = "#{old_content.rstrip} #{APPEND_THIS}#{N}"
    # ===================================================================== #
    # Append [] unless it already has that at the end of the line.
    # ===================================================================== #
    unless old_content.chomp.end_with? APPEND_THIS
      dataset[line_number - 1] = new_line
      # =================================================================== #
      # Next, honour a certain constant set at the top, IF it is true.
      # This will put the solved question on top of the exam-file at hand.
      # =================================================================== #
      if put_solved_question_on_top_of_the_file?
        dataset[line_number - 1] = nil # Delete it first.
        # ================================================================= #
        # Next, find the first line that starts with a '-' token, then
        # subtract one from it since Arrays in ruby start at 0.
        # ================================================================= #
        line_number = dataset.find_index { |inner_line|
          inner_line =~ /^- / # Note that this requires the same Encoding.
        }
        # ================================================================= #
        # Guard against nil-entries:
        # ================================================================= #
        if line_number.nil?
          etomato 'The variable line_number was nil. This may be the case'
          etomato 'when all questions have already been answered.'
          etomato 'The old target file was:'
          e
          e sfile("  #{target_file}")
          e
        end
        line_number -= 1 if line_number # Subtract 1 due to reason given above.
        dataset[line_number] = "\n#{new_line}" # Set it to the new value here.
        dataset.compact! # Chop away any possible .nil values.
      end
      # =================================================================== #
      # Store it next.
      # =================================================================== #
      if be_verbose?
        opnn; e 'Writing into the file '+sfile(target_file)+'.'
      end
      write_what_into(dataset, target_file)
      # =================================================================== #
      # And also register as to where we saved it. This may be important
      # if we wish to ftp-upload it, or for a similar purpose.
      # =================================================================== #
      into = ::Studium::LAST_SAVED_INTO_THIS_FILE
      write_what_into(target_file, into)
      if is_on_roebe? # Simply copy the dataset here.
        write_what_into(dataset, target_at_home)
        # ================================================================= #
        # Also update the studium-project in this case.
        # ================================================================= #
        cd RUBY_SRC_DIR
        opnn; e 'Since we are on roebe, we will also store into:'
        e "  #{sfile(target_at_home)}"
        rinstall2
      end
      # =================================================================== #
      # If we are on roebe, then try to load up a certain class in the
      # roebe project, and generate an updated .yml file for the
      # exam questions. This behaviour can be toggled via a constant.
      # =================================================================== #
      if is_on_roebe? and
         File.exist?(Studium::FILE_TEN_ALIASES_YML) and
         SHALL_WE_ALSO_UPDATE_THE_TEN_MAIN_ALIASES
        begin
          require 'roebe/classes/show_ten_aliases.rb'
          Roebe::ShowTenAliases.new { :be_quiet_and_ignore_existing_file }
        rescue LoadError
          opnn; e 'roebe/classes/show_ten_aliases.rb is unavailable.'
        end              
      end
      consider_updating_exam_questions_solved_today
      invoke_max_stats_class
    end
  else
    not_found = "#{NAMESPACE} Not found a line number "\
                "for #{sfancy(@which_question)}".dup
    not_found << '.' unless @which_question.end_with? '.'
    e not_found
  end
end

#set_which_question(i = Studium.file_last_question_asked?) ⇒ Object

#

set_which_question

#


119
120
121
122
123
124
125
126
127
128
# File 'lib/studium/exams/solved/solved.rb', line 119

def set_which_question(
    i = Studium.file_last_question_asked? # This may be "/root/Studium/last_question_asked.md".
  )
  if File.exist? i
    i = File.read(i).chomp
  else
    opnn; no_file_exists_at(i)
  end
  @which_question = i
end

#show_helpObject

#

show_help

#


14
15
16
17
18
19
20
21
22
# File 'lib/studium/exams/solved/help.rb', line 14

def show_help
  opnn; e 'This class will mark the given question/answer as solved.'
  opnn; e
  opnn; e 'If you want to show which question that is, pass '\
          'this option:'
  e
  e yellow('  --simulate')
  e
end

#show_which_question_we_would_mark_as_solvedObject

#

show_which_question_we_would_mark_as_solved

This method is feedback from when we pass –simulate to this class.

#


287
288
289
290
291
292
293
# File 'lib/studium/exams/solved/solved.rb', line 287

def show_which_question_we_would_mark_as_solved
  opnn; e 'The question that we would next mark as '\
          'solved, is the following one:'
  e
  e "#{sfancy(which_question?)}#{return_the_topic}"
  e
end

#which_question?Boolean Also known as: which_question

#

which_question?

#

Returns:

  • (Boolean)


278
279
280
# File 'lib/studium/exams/solved/solved.rb', line 278

def which_question?
  @which_question
end

#which_topic?Boolean

#

which_topic?

This method will determine which topic was the last one that was asked.

#

Returns:

  • (Boolean)


104
105
106
107
108
109
110
111
112
113
114
# File 'lib/studium/exams/solved/solved.rb', line 104

def which_topic?
  _ = ::Studium.last_topic?
  if File.exist? _
    return File.read(_).chomp.split('/').last
  else
    if is_on_roebe?
      opnn; no_file_exists_at(_)
    end
    ''
  end
end