Class: Studium::GenerateSpreadsheet

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/utility_scripts/generate_spreadsheet.rb

Overview

Studium::GenerateSpreadsheet

Constant Summary collapse

NAMESPACE =
#

NAMESPACE

#
inspect

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(commandline_arguments = nil, run_already = true) ⇒ GenerateSpreadsheet

#

initialize

#


54
55
56
57
58
59
60
61
62
63
64
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 54

def initialize(
    commandline_arguments = nil,
    run_already           = true
  )
  reset
  set_commandline_arguments(
    commandline_arguments
  )
  sanitize_commandline_arguments
  run if run_already
end

Class Method Details

.[](i = '') ⇒ Object

#

Studium::GenerateSpreadsheet[]

#


344
345
346
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 344

def self.[](i = '')
  new(i)
end

Instance Method Details

#check_for_the_availability_of_the_main_gemObject

#

check_for_the_availability_of_the_main_gem

#


188
189
190
191
192
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 188

def check_for_the_availability_of_the_main_gem
  if Object.const_defined? :Axlsx
    @can_we_continue = true
  end
end

#consider_opening_the_generated_fileObject

#

consider_opening_the_generated_file

#


123
124
125
126
127
128
129
130
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 123

def consider_opening_the_generated_file
  if is_on_roebe?
    begin
      require 'open'
      Open.in_editor(@generate_this_file)
    rescue LoadError; end
  end
end

#consider_removing_the_old_file(i = @generate_this_file) ⇒ Object

#

consider_removing_the_old_file

#


135
136
137
138
139
140
141
142
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 135

def consider_removing_the_old_file(
    i = @generate_this_file
  )
  if File.exist?(i) and i.end_with?('.xlsx')
    e "#{rev}Deleting the file #{sfile(i)} next." if is_on_roebe?
    File.delete(i)
  end
end

#create_new_spreadsheet_instanceObject

#

create_new_spreadsheet_instance

#


147
148
149
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 147

def create_new_spreadsheet_instance
  @p = Axlsx::Package.new
end

#main_file?Boolean

#

main_file?

#

Returns:

  • (Boolean)


337
338
339
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 337

def main_file?
  @generate_this_file
end
#

menu (menu tag)

Don't forget to add new entries to this menu.

#


156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 156

def menu(
    i = @commandline_arguments
  )
  if i.is_a? Array
    i.each {|entry| menu(entry) }
  else
    case i
    # ===================================================================== #
    # === genspreadsheet --indi4
    # ===================================================================== #
    when /^-?-?indi4$/i,
         /^-?-?Mastercurriculum(-|_| )?\(?Bio\)?Informatics(-|_| )?and(-|_| )?molecular(-|_| )?biotechnology(-|_| )?including(-|_| )?aspects(-|_| )?from(-|_| )?molecular(-|_| )?medicine$/i,
         /^-?-?Mastercurriculum(-|_| )?Informatik(-|_| )?und(-|_| )?molekulare(-|_| )?Biologie$/i
      @dataset = Studium.load_this_yaml_file(:indi4)
    # ===================================================================== #
    # === genspreadsheet --indi3
    # ===================================================================== #
    when /^-?-?indi3$/i,
         /^-?-?Bachelorcurriculum(-|_| )?Informatik(-|_| )?und(-|_| )?molekulare(-|_| )?Biologie$/i
      @dataset = Studium.load_this_yaml_file(:indi3)
    # ===================================================================== #
    # === genspreadsheet --indi2
    # ===================================================================== #
    when /^-?-?indi2$/i
      @dataset = Studium.load_this_yaml_file(:indi2)
    end
  end
end

#resetObject

#

reset (reset tag)

#


69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 69

def reset
  super()
  # ======================================================================= #
  # === @namespace
  # ======================================================================= #
  @namespace = NAMESPACE
  # ======================================================================= #
  # === @dataset_from_the_file_lecture_information
  # ======================================================================= #
  @dataset_from_the_file_lecture_information =
    return_dataset_from_the_file_lecture_information
  # ======================================================================= #
  # === @generate_this_file
  #
  # Save into this file here.
  # ======================================================================= #
  @generate_this_file = 'studium.xlsx'
  # ======================================================================= #
  # === @dataset
  #
  # This variable will eventually keep track of the dataset that will
  # be used in order to generate the dataset for the excel-file at
  # hand.
  # ======================================================================= #
  @dataset = nil
  # ======================================================================= #
  # === @size_of_the_header_font
  # ======================================================================= #
  @size_of_the_header_font = 18
  # ======================================================================= #
  # === @can_we_continue
  # ======================================================================= #
  @can_we_continue = false
end

#runObject

#

run (run tag)

#


197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 197

def run
  menu
  check_for_the_availability_of_the_main_gem
  if @can_we_continue
    consider_removing_the_old_file
    # ======================================================================= #
    # Trigger this via:
    #
    #   genspreadsheet --indi2
    #
    # ======================================================================= #
    create_new_spreadsheet_instance
    begin
      require 'caxlsx'
    rescue LoadError; end
    @p = Axlsx::Package.new
    wb = @p.workbook
    wb.styles { |style|
      # ===================================================================== #
      # Next define some different styles that could be used.
      # ===================================================================== #
      _larger_font     = wb.styles.add_style(sz: main_font_size?)
      larger_font_and_centered_alignment = wb.styles.add_style(
        sz: main_font_size?, alignment: { horizontal: :center }
      )
      larger_font_and_centered_alignment_and_border = wb.styles.add_style(
        sz: main_font_size?, alignment: { horizontal: :center },
        border: Axlsx::STYLE_THIN_BORDER
      )
      _medium_font      = wb.styles.add_style(sz: 16)
      highlighted_and_centered_cell    = wb.styles.add_style(
        bg_color: 'EFC376', # ← Set a background colour.
        alignment: { horizontal: :center }
      )
      _center_alignment = wb.styles.add_style(
        { :alignment => { horizontal: :center } }
      )
      _red_border = wb.styles.add_style(
        :border => {
          color: 'FF0000',
          style: :thin
        }
      )
      # ===================================================================== #
      # Define the default style-Array next:
      # ===================================================================== #
      use_this_style_array = [
        highlighted_and_centered_cell,
        larger_font_and_centered_alignment,
        larger_font_and_centered_alignment_and_border,
        larger_font_and_centered_alignment,
        larger_font_and_centered_alignment,
        larger_font_and_centered_alignment
      ]
      wb.add_worksheet(name: 'Curriculum') {|sheet|
        sheet.add_row(
          [
            '#',                             # 1)
            'Universität',                   # 2)
            'LVA ID',                        # 3)
            'Name der Lehrveranstaltung',    # 4)
            'Modul',                         # 5)
            'n ECTS',                        # 6)
            'LVA Typ'                        # 7)
          ],
          style: use_this_style_array,
          sz: @size_of_the_header_font
        )
        sheet.add_row
        sheet.add_row
        index = 0
        if @dataset.nil?
          e 'No '+steelblue('@dataset')+' was found. Thus, no excel '\
            'file can be generated.'
          return
        end
        @dataset.each {|entry| index += 1
          splitted = entry.split(' ')
          lva_id = splitted.first.to_s
          name_of_the_lecture = splitted[1 .. -1].join(' ').strip
          # ================================================================= #
          # Determine the university next.
          # ================================================================= #
          this_university = @dataset_from_the_file_lecture_information[entry][:university].to_s.strip
          n_ects          = @dataset_from_the_file_lecture_information[entry][:ects].to_s.strip
          n_ects          = '%.1f' % n_ects.to_f
          lva_typ         = @dataset_from_the_file_lecture_information[entry][:type].to_s.strip
          sheet.add_row(
            [
              index.to_s,           # 1)
              this_university,      # 2)
              lva_id.to_s,          # 3)
              name_of_the_lecture,  # 4)
              '(unknown module)',   # 5)
              n_ects,               # 6)
              lva_typ               # 7)
            ],
            style: use_this_style_array,
            sz: 18
          )
          sheet.add_hyperlink(
            location: Studium.return_url_from(entry).to_s,
            ref:      sheet.rows.last.cells.first
          )
          sheet.rows.last.cells.each {|this_cell|
            this_cell.b = true
          }
          #sheet.rows.last.cells[1].border = { :style => :thick, :color =>'FF0000FF' }
          # cell_value_of_the_lva_type = sheet.rows.last.cells[5].value
          # if is_prüfungsimmanent?(cell_value_of_the_lva_type)
          #   # Modify prüfungsimmanente lectures next:
          #   sheet.rows.last.cells[5].style = [red_border]
          # end
          # sheet.rows.last.cells[1].border_width = 10
          # sheet.add_hyperlink(
          #   location: Studium.return_url_from(entry),
          #   target:   Studium.return_url_from(entry),
          #   ref: "A#{index}"
          # )
        }
      }
    }
    @p.serialize(main_file?)
    if File.exist? @generate_this_file
      opnn; e 'Saving into the file `'+
               sfile(@generate_this_file)+'`.'
      consider_opening_the_generated_file
    end
  else
    e 'The main gem (gem install axlsx) '\
      'is not available - thus we can not continue.'
    # if is_on_roebe?
    #   esystem 'gem install axlsx'
    # end
  end
end

#sanitize_commandline_argumentsObject

#

sanitize_commandline_arguments

#


114
115
116
117
118
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 114

def sanitize_commandline_arguments
  if @commandline_arguments.empty? and is_on_roebe?
    @commandline_arguments << :indi2
  end
end

#size_of_the_header_font?Boolean Also known as: main_font_size?

#

size_of_the_header_font?

#

Returns:

  • (Boolean)


107
108
109
# File 'lib/studium/utility_scripts/generate_spreadsheet.rb', line 107

def size_of_the_header_font?
  @size_of_the_header_font
end