Class: Studium::IndividualResolvePracticalCoursesDateConflicts

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb

Overview

IndividualResolvePracticalCoursesDateConflicts.new

Constant Summary

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::NAMESPACE, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(name_of_the_lecture = nil, dataset = nil, run_already = true) ⇒ IndividualResolvePracticalCoursesDateConflicts

#

initialize

#


28
29
30
31
32
33
34
35
36
37
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 28

def initialize(
    name_of_the_lecture = nil,
    dataset             = nil,
    run_already         = true
  )
  reset
  set_name_of_the_lecture(name_of_the_lecture)
  set_dataset(dataset)
  run if run_already
end

Class Method Details

.[](i = '') ⇒ Object

#

[]

#


183
184
185
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 183

def self.[](i = '')
  new(i)
end

Instance Method Details

#allowed_time?(i) ⇒ Boolean Also known as: allowed_range?

#

allowed_time?

This method will return true if the input is an allowed time, and false otherwise.

#

Returns:

  • (Boolean)


237
238
239
240
241
242
243
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 237

def allowed_time?(i)
  i = i.begin
  termine = termine?
  termine.any? {|range_object|
    range_object.cover? i
  }
end

#cleanupObject

#

cleanup

#


142
143
144
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 142

def cleanup
  remove_instance_variable(:@dataset)
end

#dataset?Boolean

#

dataset?

#

Returns:

  • (Boolean)


135
136
137
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 135

def dataset?
  @dataset
end

#general_priority?Boolean Also known as: priority?

#

general_priority?

#

Returns:

  • (Boolean)


81
82
83
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 81

def general_priority?
  @general_priority
end

#has_conflict_with?(i) ⇒ Boolean Also known as: has_any_conflict_with?, has_any_conflict?

#

has_conflict_with?

This will return true if there is a conflict with the given input time; and false otherwise.

The input should be an Array.

#

Returns:

  • (Boolean)


195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 195

def has_conflict_with?(i)
  is_there_a_conflict = false
  first_days = i.map {|range_object| range_object.begin }
  _ = termine?
  first_days.each {|beginning_day_for_the_course|
    if _.any? {|inner_entry|
        inner_entry.cover? beginning_day_for_the_course
      }
      is_there_a_conflict = true
    end
  }
  return is_there_a_conflict # More explicit return.
end

#has_these_conflicts_with?(i) ⇒ Boolean Also known as: has_these_conflicts?

#

has_these_conflicts_with?

#

Returns:

  • (Boolean)


222
223
224
225
226
227
228
229
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 222

def has_these_conflicts_with?(i)
  i.select {|line|
    starting_day = line.begin
    termine?.select {|inner_line|
      inner_line.cover? starting_day
    }
  }
end

#name_of_the_lecture?Boolean Also known as: name?

#

name_of_the_lecture?

#

Returns:

  • (Boolean)


88
89
90
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 88

def name_of_the_lecture?
  @name_of_the_lecture
end

#parse_datasetObject

#

parse_dataset

#


54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 54

def parse_dataset
  _ = @dataset
  set_termine(
    _['termine']
  )
  sanitize_termine
  set_general_priority ensure_main_encoding(_['general_priority'])
  set_uniwien_priorität(
    ensure_main_encoding(
      _['uniwien_priorität']
    )
  )
  set_vorbesprechung(_['vorbesprechung'])
end

#resetObject

#

reset (reset tag)

#


42
43
44
45
46
47
48
49
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 42

def reset
  super()
  @termine             = nil
  @vorbesprechung      = nil
  @general_priority    =   0
  @uniwien_priorität   =   0
  @name_of_the_lecture = nil
end

#runObject

#

run (run tag)

#


248
249
250
251
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 248

def run
  parse_dataset
  cleanup
end

#sanitize_termine(i = termine?) ) ⇒ Object

#

sanitize_termine

We are only interested in uniq entries, hence the call towards .uniq().

#


176
177
178
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 176

def sanitize_termine(i = termine?)
  @termine = turn_input_into_real_dates(i).uniq
end

#set_dataset(i = '') ⇒ Object

#

set_dataset

#


128
129
130
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 128

def set_dataset(i = '')
  @dataset = i
end

#set_general_priority(i = nil) ⇒ Object

#

set_general_priority

#


72
73
74
75
76
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 72

def set_general_priority(i = nil)
  i = 0 if i.nil?
  i = i.to_i if i.is_a? String
  @general_priority = i
end

#set_name_of_the_lecture(i) ⇒ Object

#

set_name_of_the_lecture

#


95
96
97
98
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 95

def set_name_of_the_lecture(i)
  i = ensure_main_encoding(i)
  @name_of_the_lecture = i
end

#set_termine(i) ⇒ Object

#

set_termine

#


121
122
123
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 121

def set_termine(i)
  @termine = i
end

#set_uniwien_priorität(i) ⇒ Object

#

set_uniwien_priorität

#


103
104
105
106
107
108
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 103

def set_uniwien_priorität(i)
  if i.is_a? String
    i = i.to_i
  end
  @uniwien_priorität = i
end

#set_vorbesprechung(i) ⇒ Object

#

set_vorbesprechung

#


113
114
115
116
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 113

def set_vorbesprechung(i)
  i = ensure_main_encoding(i)
  @vorbesprechung = i
end

#termine?Boolean

#

termine?

#

Returns:

  • (Boolean)


149
150
151
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 149

def termine?
  @termine
end

#to_germanObject

#

to_german

#


213
214
215
216
217
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 213

def to_german
  _ = termine?
  _.map! {|entry| german_date_notation(entry) }
  set_termine(_)
end

#turn_input_into_real_dates(i) ⇒ Object Also known as: array_map_to_time

#

turn_input_into_real_dates

#


156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/studium/utility_scripts/resolve_practical_courses_date_conflicts/individual_resolve_practical_courses_date_conflicts.rb', line 156

def turn_input_into_real_dates(i)
  if i.is_a? Array
    i.map! {|line|
      if line.include? '-'
        splitted = line.split('-')
        start_date = Time.at(Time.parse(splitted[0]).to_i)
        end_date   = Time.at(Time.parse(splitted[1]).to_i)
        line = start_date .. end_date # <- Turn it into a time-range.
      end
      line
    }
  end
  i
end