Class: Studium::PriorityPoints

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/utility_scripts/priority_points.rb

Overview

Studium::PriorityPoints

Constant Summary

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::NAMESPACE, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(i = nil, run_already = true) ⇒ PriorityPoints

#

initialize

#


28
29
30
31
32
33
34
35
# File 'lib/studium/utility_scripts/priority_points.rb', line 28

def initialize(
    i           = nil,
    run_already = true
  )
  reset
  set_input(i)
  run if run_already
end

Class Method Details

.[](i = '') ⇒ Object

#

Studium::PriorityPoints[]

#


255
256
257
# File 'lib/studium/utility_scripts/priority_points.rb', line 255

def self.[](i = '')
  new(i)
end

Instance Method Details

#colourize_for_ects(i) ⇒ Object Also known as: colourize_ects_points

#

colourize_for_ects

#


248
249
250
# File 'lib/studium/utility_scripts/priority_points.rb', line 248

def colourize_for_ects(i)
  springgreen(i)
end

#display_all_ranked_lecturesObject

#

display_all_ranked_lectures

This method will simply output all lectures that have specific priority points assigned.

#


143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/studium/utility_scripts/priority_points.rb', line 143

def display_all_ranked_lectures
  _ = @dataset.select {|a,b|
    b.has_key?(:priority_points)
  }.sort_by {|a,b|
    b[:priority_points]
  }.reverse
  if _
    counter = 0
    e
    # ===================================================================== #
    # Next, honour the variable @show_only_unsolved_lectures if it is
    # set to true.
    # ===================================================================== #
    if @show_only_unsolved_lectures
      _.reject! {|a, inner_hash|
        (inner_hash[:already_solved] == true)
      }
    end
    # ===================================================================== #
    # Iterate over the dataset:
    # ===================================================================== #
    _.each {|a, inner_hash| counter += 1
      lecture_type = inner_hash[:type]
      already_solved_or_not = inner_hash[:already_solved]
      this_university = inner_hash[:university]
      curricula = inner_hash['curricula']
      index = (counter.to_s+') ').rjust(4)
      result = royalblue(index)+seagreen(a)
      if inner_hash.has_key? :priority_points
        priority_points = inner_hash[:priority_points]
      end
      if @show_ects_points
        n_ects_points = inner_hash[:ects]
        curricula.each {|this_curriculum|
          @hash_attribute_ects_points_to_the_lectures_in_different_curricula[this_curriculum] += n_ects_points
        }
        @n_ects_points += n_ects_points
        @hash_ects_points_attributed_to_the_different_universities[this_university] += n_ects_points
        if is_prüfungsimmanent? lecture_type
          @n_ects_points_as_mandatory_lecture += n_ects_points
        end
        result = result.ljust(145)
        result << ' '+colourize_ects_points(
          n_ects_points.to_s.rjust(4)+' ECTS points'
        )
      end
      # =================================================================== #
      # Add the priority score next:
      # =================================================================== #
      result << crimson(
        ' '+priority_points.to_s.rjust(4)+' priority score'
      )
      # =================================================================== #
      # Already solved or not:
      # =================================================================== #
      if already_solved_or_not == true
        result << lightgreen(' Already solved')
      end
      # =================================================================== #
      # Next, output out findings.
      # =================================================================== #
      e result
    }; e
    if @show_ects_points
      result = colourize_ects_points(@n_ects_points.to_s)+
               ' ECTS points in the ^^^ above lectures'
      result << ' ('+
                colourize_ects_points(@n_ects_points_as_mandatory_lecture.to_s)+
                ' ECTS are "prüfungsimmanent")'
      e result
    end
  end
  e # Add a newline as spacer.
  Studium.report_attributed_lectures_to_universities(
    @hash_ects_points_attributed_to_the_different_universities
  )
  display_ects_points_in_different_curricula
end

#display_ects_points_in_different_curriculaObject

#

display_ects_points_in_different_curricula

#


225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/studium/utility_scripts/priority_points.rb', line 225

def display_ects_points_in_different_curricula
  _ = @hash_attribute_ects_points_to_the_lectures_in_different_curricula
  sorted = _.sort_by {|a, n_ects_points|
    n_ects_points
  }.reverse
  e
  e 'These lectures are attributed to the following curricula:'
  e
  sorted.each {|curriculum_number, n_ects_points|
    curriculum_name = return_curriculum_name_of_this_curriculum_number(curriculum_number)
    unless curriculum_name.include? 'Lehramt' # Ignore Lehramt-Curricula.
      e '  '+
        royalblue((curriculum_name).ljust(81))+
        ' '+
        slateblue(n_ects_points.to_s.rjust(4)+' ECTS points')
    end
  }
  e
end

#do_show_only_unsolved_lecturesObject

#

do_show_only_unsolved_lectures

#


76
77
78
# File 'lib/studium/utility_scripts/priority_points.rb', line 76

def do_show_only_unsolved_lectures
  @show_only_unsolved_lectures = true
end

#input?Boolean

#

input?

#

Returns:

  • (Boolean)


91
92
93
# File 'lib/studium/utility_scripts/priority_points.rb', line 91

def input?
  @input
end
#

menu (menu tag)

#


106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/studium/utility_scripts/priority_points.rb', line 106

def menu(
    i = @input
  )
  if i.is_a? Array
    i.each {|entry| menu(entry) }
  else
    case i
    # ===================================================================== #
    # === ppriority --help
    # ===================================================================== #
    when /help/
      show_help
    # ===================================================================== #
    # === ppriority --show-only-unsolved-lectures
    # ===================================================================== #
    when /^-?-?show(-|_)?only(-|_)?unsolved(-|_)?lectures$/
      do_show_only_unsolved_lectures
    end
  end
end

#resetObject

#

reset (reset tag)

#


40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/studium/utility_scripts/priority_points.rb', line 40

def reset
  super()
  # ======================================================================= #
  # === @dataset
  # ======================================================================= #
  @dataset = return_dataset_from_the_file_lecture_information
  # ======================================================================= #
  # === @show_ects_points
  #
  # If true we will show the associated ECTS points.
  # ======================================================================= #
  @show_ects_points = true
  # ======================================================================= #
  # === @n_ects_points
  # ======================================================================= #
  @n_ects_points = 0
  @n_ects_points_as_mandatory_lecture = 0
  # ======================================================================= #
  # === @hash_ects_points_attributed_to_the_different_universities
  # ======================================================================= #
  @hash_ects_points_attributed_to_the_different_universities = {}
  @hash_ects_points_attributed_to_the_different_universities.default = 0
  @hash_attribute_ects_points_to_the_lectures_in_different_curricula = {}
  @hash_attribute_ects_points_to_the_lectures_in_different_curricula.default = 0
  # ======================================================================= #
  # === @show_only_unsolved_lectures
  #
  # If the next instance variable is true, then we will only show those
  # lectures that have not yet been passed successfully.
  # ======================================================================= #
  @show_only_unsolved_lectures = false
end

#runObject

#

run (run tag)

#


98
99
100
101
# File 'lib/studium/utility_scripts/priority_points.rb', line 98

def run
  menu
  display_all_ranked_lectures
end

#set_input(i = '') ⇒ Object

#

set_input

#


83
84
85
86
# File 'lib/studium/utility_scripts/priority_points.rb', line 83

def set_input(i = '')
  i = [i].flatten # At this point we have an Array.
  @input = i
end

#show_helpObject

#

show_help (help tag)

#


130
131
132
133
134
135
# File 'lib/studium/utility_scripts/priority_points.rb', line 130

def show_help
  e
  e '  ppriority --show-only-unsolved-lectures # show only lectures '\
    'that were not yet completed successfully'
  e
end