Class: Studium::ShowPassedCreditsPerCurriculum

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/ects/show_passed_credits_per_curriculum.rb

Overview

Studium::ShowPassedCreditsPerCurriculum.new

Constant Summary collapse

NAMESPACE =
#

NAMESPACE

#
inspect

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(i = nil, run_already = true) ⇒ ShowPassedCreditsPerCurriculum

#

initialize

#


31
32
33
34
35
36
37
38
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 31

def initialize(
    i           = nil,
    run_already = true
  )
  reset
  set_input(i)
  run if run_already
end

Class Method Details

.[](i = '') ⇒ Object

#

Studium::ShowPassedCreditsPerCurriculum[]

#


260
261
262
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 260

def self.[](i = '')
  new(i)
end

Instance Method Details

#input?Boolean

#

input?

#

Returns:

  • (Boolean)


97
98
99
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 97

def input?
  @input
end

#iterate_over_the_curriculaObject

#

iterate_over_the_curricula

#


111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 111

def iterate_over_the_curricula
  _ = @dataset_from_the_file_lecture_information
  e
  # ======================================================================= #
  # The following instance variable, @use_these_curricula, has entries
  # such as :master_vector.
  # ======================================================================= #
  @use_these_curricula.each {|this_curriculum|
    if this_curriculum.to_s.start_with?('master_') and
      !(@already_showed_a_red_spacer == true)
      show_a_red_spacer
      @already_showed_a_red_spacer = true
    end
    # ===================================================================== #
    # Entries such as :bachelor_genetics are also conjugate, so we have
    # to solve this at a later time.
    # ===================================================================== #
    array_curriculum_files = return_path_of_this_curriculum(this_curriculum)
    array_curriculum_files = [array_curriculum_files] unless array_curriculum_files.is_a? Array
    # ===================================================================== #
    # Next, obtain the dataset.
    # ===================================================================== #
    dataset = []
    array_curriculum_files.each {|this_curriculum_file|
      file_content = read_file(this_curriculum_file)
      dataset << sanitize_dataset(file_content)
      dataset.flatten!
    }
    dataset.reject {|line| line.empty? }.each {|name_of_the_lecture|
      pointer = _[name_of_the_lecture]
      # =================================================================== #
      # Next, since as of March 2022, we need to check whether an
      # alias may exist for the lecture at hand. If so, and if the
      # above pointer is nil, then we will ad-hoc change this,
      # to account for the fact that some lectures may have another
      # LVA id now.
      # =================================================================== #
      splitted = name_of_the_lecture.split(' ')
      old_LVA_ID = splitted.first
      short_name_of_the_lecture = splitted[1..-1].join(' ')
      if pointer.nil? and @dataset_from_the_file_lecture_aliases.include?(short_name_of_the_lecture)
        dataset_from_the_file_lecture_aliases = @dataset_from_the_file_lecture_aliases[short_name_of_the_lecture]
        if dataset_from_the_file_lecture_aliases.has_key?(:old_lva_id) and
          (dataset_from_the_file_lecture_aliases[:old_lva_id] == old_LVA_ID)
          pointer = dataset_from_the_file_lecture_aliases[:new_lva_id]+' '+short_name_of_the_lecture
          pointer = _[pointer]
        end
      end
      if pointer.nil?
        e steelblue(name_of_the_lecture)
        opnn; e swarn('A problem was encountered.')
        opnn; e swarn('Is the following lecture available? → ')+
                sfancy(name_of_the_lecture)
        opnn; e crimson('We will also show the original dataset:')
        e
        pp dataset
        e
        exit # Exiting seems to be better in the long run.
      else
        if pointer.has_key? :ects
          n_ects_points  = pointer[:ects]
          already_solved = pointer[:already_solved]
          if already_solved == true
            @n_ects_solved += n_ects_points
          end
          @total_ects_in_this_curriculum += n_ects_points
        else
          e "No :ects entry for the lecture "\
            "#{sfancy(name_of_the_lecture)}"
        end
      end
    }
    n_percentage = (
      (@n_ects_solved.to_f * 100) / @total_ects_in_this_curriculum
    ).round(2).to_s
    # ===================================================================== #
    # Padd it a bit to the right, so that percentage values below
    # 10 will also be properly aligned.
    # ===================================================================== #
    n_percentage = n_percentage.rjust(5,' ')
    n_percentage = n_percentage.ljust(5,'0')
    n_percentage << '%'
    prettier_name_of_the_curriculum = return_prettier_name_for(this_curriculum)
    if this_curriculum.size > 36 # Check against the original name.
      prettier_name_of_the_curriculum = prettier_name_of_the_curriculum[0 .. 33]+' [...]'
    end
    # ===================================================================== #
    # Finally, display the result next.
    # ===================================================================== #
    n_ects_were_solved_padded_display = sfancy(@n_ects_solved.to_s.rjust(5))+' ECTS'
    e '  '+sfancy(prettier_name_of_the_curriculum)+' '+
      ' solved '+n_ects_were_solved_padded_display+'
       out of '+
      sfancy(@total_ects_in_this_curriculum.to_s.rjust(5))+
      ' ECTS points in this '\
      'curriculum. ('+slateblue(n_percentage)+')'
    reset_ects_variables
  }; e
end

#main_dataset?Boolean

#

main_dataset?

#

Returns:

  • (Boolean)


81
82
83
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 81

def main_dataset?
  @dataset_from_the_file_lecture_information
end

#resetObject

#

reset (reset tag)

#


43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 43

def reset
  super()
  # ======================================================================= #
  # === @namespace
  # ======================================================================= #
  @namespace = NAMESPACE
  # ======================================================================= #
  # === @use_these_curricula
  #
  # Determine which curricula are to be checked by this class.
  # ======================================================================= #
  @use_these_curricula = ARRAY_REGISTERED_CURRICULA
  # ======================================================================= #
  # === @dataset_from_the_file_lecture_information
  # ======================================================================= #
  @dataset_from_the_file_lecture_information = return_dataset_from_file_lecture_information
  # ======================================================================= #
  # === @dataset_from_the_file_lecture_aliases
  # ======================================================================= #
  @dataset_from_the_file_lecture_aliases = YAML.load_file(Studium.file_lecture_aliases)
  # ======================================================================= #
  # === @already_showed_a_red_spacer
  # ======================================================================= #
  @already_showed_a_red_spacer = false
  reset_ects_variables
end

#reset_ects_variablesObject

#

reset_ects_variables

#


73
74
75
76
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 73

def reset_ects_variables
  @n_ects_solved = 0
  @total_ects_in_this_curriculum = 0
end

#return_prettier_name_for(i) ⇒ Object

#

return_prettier_name_for

#


214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 214

def return_prettier_name_for(i)
  i = i.to_s
  if i.include? 'bachelor_'
    i.sub!(/bachelor_/,'Bachelorcurriculum ')
    i = i.split(' ').map(&:capitalize).join(' ')
  elsif i.include? 'master_'
    i.sub!(/master_/,'Mastercurriculum ')
    i = i.split(' ').map(&:capitalize).join(' ')
  end
  if i.include? '_'
    i = i.split('_').map(&:capitalize).join(' ')
  end
  i.ljust(40)
end

#runObject

#

run (run tag)

#


253
254
255
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 253

def run
  iterate_over_the_curricula
end

#sanitize_dataset(i) ⇒ Object

#

sanitize_dataset

#


232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 232

def sanitize_dataset(i)
  if i.is_a? String
    i = i.split(N)
  end
  i.reject! {|entry|
    entry.strip.empty? or entry.start_with?('#')
  }
  i.map! {|line|
    if line.include?('#')
      line = line[0 .. ( line.index('#') - 1)]
    end
    line.chomp
  }
  i.map! {|line| line.squeeze(' ') }
  i.map!(&:strip)
  i
end

#set_input(i = '') ⇒ Object

#

set_input

#


88
89
90
91
92
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 88

def set_input(i = '')
  i = i.first if i.is_a? Array
  i = i.to_s.dup
  @input = i
end

#show_a_red_spacerObject

#

show_a_red_spacer

#


104
105
106
# File 'lib/studium/ects/show_passed_credits_per_curriculum.rb', line 104

def show_a_red_spacer
  e '  '+swarn('=' * 108)
end