Class: Studium::Stundenplan

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/utility_scripts/stundenplan.rb

Overview

Studium::Stundenplan

Constant Summary collapse

NAMESPACE =
#

NAMESPACE

#
inspect
COLOUR_FOR_NAME_OF_UNIVERSITY =
#

COLOUR_FOR_NAME_OF_UNIVERSITY

#
::Colours::CYAN
COLOUR_FOR_TITLE =
#

COLOUR_FOR_TITLE

#
::Colours::MAGENTA
COLOUR_FOR_LEGENDE =
#

COLOUR_FOR_LEGENDE

#
::Colours::RED
MAIN_FILE =
#

MAIN_FILE

MAIN_FILE = '/home/x/STUDIUM/YAML/was_ich_machen_moechte_ws2013.yml'

#
"#{STUDIUM_YAML_DIR}stundenplan.yml"
SOFFICE =
#

SOFFICE

#
'/opt/libreoffice/program/soffice'
THIS_FILE =
#

THIS_FILE

#
__FILE__
ARRAY_WITH_TIMES =
#

ARRAY_WITH_TIMES

#
%w(
  08:00-09:00
  09:00-10:00
  10:00-11:00
  11:00-12:00
  12:00-13:00
  13:00-14:00
  14:00-15:00
  15:00-16:00
  16:00-17:00
  17:00-18:00
  18:00-19:00
  19:00-20:00
  20:00-21:00
)

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(i = nil, run_already = true) ⇒ Stundenplan

#

initialize

#


103
104
105
106
107
108
109
110
# File 'lib/studium/utility_scripts/stundenplan.rb', line 103

def initialize(
    i           = nil,
    run_already = true
  )
  reset
  set_input(i)
  run if run_already
end

Instance Method Details

#alle_vorlesungenObject

#

alle_vorlesungen

#


378
379
380
# File 'lib/studium/utility_scripts/stundenplan.rb', line 378

def alle_vorlesungen
  @data.keys
end

#colourize_this_university(i) ⇒ Object

#

colourize_this_university

#


439
440
441
# File 'lib/studium/utility_scripts/stundenplan.rb', line 439

def colourize_this_university(i)
  return COLOUR_FOR_NAME_OF_UNIVERSITY+i+COLOUR_FOR_TITLE
end

#create_spreadsheetObject

#

create_spreadsheet (xls tag)

Use this method to create a stundenplan.xls file.

#


488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
# File 'lib/studium/utility_scripts/stundenplan.rb', line 488

def create_spreadsheet
  require 'spreadsheet'
  create_xlsfile_where = '/stundenplan.xls'
  try_remove(create_xlsfile_where)
  Spreadsheet.client_encoding = 'UTF-8'
  book = Spreadsheet::Workbook.new
  opnn; e 'We will store at `'+sfile(create_xlsfile_where)+'`.'
  sheet1 = book.create_worksheet :name => 'Stundenplan'
  sheet1.row(0).height = 22
  sheet1.row(0).concat ['']+ARRAY_WITH_TIMES
  # ======================================================================= #
  # Work on each weekday, Monday to Friday.
  # ======================================================================= #
  %w(
    Montag Dienstag Mittwoch Donnerstag Freitag
  ).each_with_index {|weekday, index|
    @all_days[weekday[0,2].downcase.to_sym].each {|lecture|
      # =================================================================== #
      # Format:
      #   "Organische Chemie 1","10.00 - 12.00"
      # =================================================================== #
      # title     = lecture[0]
      # =================================================================== #
      starts_when = lecture[1].delete(' ').tr('.',':')
      if starts_when.include? ','
        starts_when = starts_when[0, starts_when.index(',')]
      end
      # ARRAY_WITH_TIMES.find_index {|entry| entry == "10:00-11:00"}
    }
    this_row = sheet1.row(index+1)
    this_row.concat [ weekday ]
  }
  book.write(create_xlsfile_where)
  esystem SOFFICE+' '+create_xlsfile_where
end

#display_stundenplan_on_the_terminalObject

#

display_stundenplan_on_the_terminal

#


239
240
241
242
# File 'lib/studium/utility_scripts/stundenplan.rb', line 239

def display_stundenplan_on_the_terminal
  _ = readlines_from_this_input_file(MAIN_FILE)
  _.each {|line| e line }
end

#generate_pdf_fileObject

#

generate_pdf_file (pdf tag)

Use this method to generate a .pdf file.

#


537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
# File 'lib/studium/utility_scripts/stundenplan.rb', line 537

def generate_pdf_file
  create_pdffile_where = '/STUNDENPLAN.pdf'
  try_remove(create_pdffile_where)
  opnn; e 'We will store at `'+sfile(create_pdffile_where)+'`.'
  pdf = Prawn::Document.new(:page_size => 'A4')
  pdf.font 'Times-Roman'
  pdf.text 'Stundenplan', :size => 50,
    :align => :center, :styles => :bold
  require 'cyberweb'
  img = Cyberweb.random_web_image
  # Next, the various weekdays: 
  %w(
    Montag Dienstag Mittwoch Donnerstag Freitag
  ).each_with_index {|weekday, index|
    # pdf.image filename, :at => [10, 10], :width => 15
    # pdf.image WebImages.random, :width => 15
    pdf.image(img)
    pdf.text(
      weekday.to_s.encode('UTF-8'),
      :size => 28, :color => 'black', :fill_color => '0000ff',
      :styles => :underline
    )
    @all_days[weekday[0,2].downcase.to_sym].each {|lecture|
      starts_when = starts_when.tr('.',':')
      pdf.fill_color '0000ff'
      if lecture[0].valid_encoding?
        lecture[0]  = lecture[0].encode('UTF-8')
        starts_when = starts_when.encode('UTF-8')
        pdf.indent(15) { pdf.text(lecture[0]+':'+N) }
        pdf.fill_color '#000000' # This is the black colour.
        pdf.indent(25) { pdf.text('    '+starts_when) }
      else
        opnn; e 'Something is not correct with the encoding.'
      end
    }
  }
  pdf.render_file(create_pdffile_where)
  PdfParadise::MainPdf.new(create_pdffile_where)
end

#get_location_of(i) ⇒ Object

#

get_location_of

#


256
257
258
259
260
261
262
263
264
# File 'lib/studium/utility_scripts/stundenplan.rb', line 256

def get_location_of(i)
  if @data.has_key? i
    result = @data[i]['Wo'].to_s
    result = '(unknown)' if result.empty?
    return result
  else
    return i
  end
end

#get_priority_of(i) ⇒ Object

#

get_priority_of

This will return the priority of the given lecture.

#


249
250
251
# File 'lib/studium/utility_scripts/stundenplan.rb', line 249

def get_priority_of(i)
  @data[i]['Priority'].to_s if @data.has_key? i
end

#get_title_of(i) ⇒ Object

#

get_title_of

This method gets the title. Input must be the ID of the Lecture.

#


417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/studium/utility_scripts/stundenplan.rb', line 417

def get_title_of(i)
  if i and @data.has_key? i
    title = @data[i]['Title'].to_s
    if title.include?    'BOKU'
      title.gsub!(/BOKU/,
        colourize_this_university('BOKU'))
    elsif title.include? 'UNI Wien'
      title.gsub!(/UNI Wien/,
        colourize_this_university('UNI Wien'))
    elsif title.include? 'TU Wien'
      title.gsub!(/TU Wien/,
        colourize_this_university('TU Wien'))
    end
    return title
  else
    return i
  end
end

#get_vorbesprechung_of(i) ⇒ Object

#

get_vorbesprechung_of

#


269
270
271
272
# File 'lib/studium/utility_scripts/stundenplan.rb', line 269

def get_vorbesprechung_of(i) # <-- This here can return nil.
  i = @data[i]['Vorbesprechung'] if i.is_a? Hash
  return i
end

#heute_istObject

#

heute_ist

#


385
386
387
388
389
# File 'lib/studium/utility_scripts/stundenplan.rb', line 385

def heute_ist
  if @may_we_show_the_result
    e 'Heute ist der '+simp(@date)+', ein '+@wochentag+'.'
  end
end

#my_clinerObject

#

my_cliner

#


277
278
279
# File 'lib/studium/utility_scripts/stundenplan.rb', line 277

def my_cliner
  cliner '','',Colours::GRAY
end

#open_stundenplan_in_editorObject

#

open_stundenplan_in_editor

#


231
232
233
234
# File 'lib/studium/utility_scripts/stundenplan.rb', line 231

def open_stundenplan_in_editor
  _ = Studium.editor?+' '+MAIN_FILE
  e _; system _; exit
end

#open_this_file_in_editor(shall_we_exit = true) ⇒ Object

#

open_this_file_in_editor

#


222
223
224
225
226
# File 'lib/studium/utility_scripts/stundenplan.rb', line 222

def open_this_file_in_editor(shall_we_exit = true)
    _ = Studium.editor?+' '+THIS_FILE
  e _; system _
  exit if shall_we_exit
end

#process_datasetObject

#

process_dataset

#


333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/studium/utility_scripts/stundenplan.rb', line 333

def process_dataset
  @data.keys.each {|key|
    wann = @data[key]['Wann']
    if wann # This should be a Hash, not a String.
      # Sometimes it is not a Hash though.
      if wann.is_a? String
        hash = {}
        array = wann.split(N).reject {|line| line.start_with? '#' }
        # Now it is an Array.
        array.each {|entry|
          _ = entry.split(' ')
          key = _[0]
          new_value = _[1..-1].join(' ')
          if hash.has_key? key
            hash[key] = hash[key]+' '+new_value 
          else
            hash[key] = new_value
          end
        }
        wann = hash
      end
      wann.each_pair {|inner_key, new_value|
        inner_key = inner_key.delete(N)
        the_day = inner_key.downcase.to_sym
        begin
          new_value.gsub!(/ Uhr/,'') if new_value.include? 'Uhr'
        rescue Exception => error; p error; end
        array = [
          get_title_of(key),
          new_value,
          get_priority_of(key),
          get_location_of(key),
          get_vorbesprechung_of(key) # <-- This here can return nil.
        ]
        @all_days[the_day] << array
      }
    else
      opnn; e 'Warning: no Wann entry found for '+sfancy(key)+'.'
    end
  } # Now we have @all_days set.
end

#remove(i) ⇒ Object Also known as: try_remove

#

remove

#


467
468
469
470
471
472
# File 'lib/studium/utility_scripts/stundenplan.rb', line 467

def remove(i)
  if File.exist? i
    opnn; e 'Removing file '+sfile(i)+'.'
    FileUtils.rm(i)
  end
end

#resetObject

#

reset

#


306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/studium/utility_scripts/stundenplan.rb', line 306

def reset # reset tag
  super()
  # ======================================================================= #
  # === @namespace
  # ======================================================================= #
  @namespace = NAMESPACE
  # ======================================================================= #
  # === @input
  # ======================================================================= #
  @input = ''.dup
  @may_we_show_the_result = true # if true, we may output the result.
  @wochentag = ENGLISH_TO_GERMAN_WEEKDAY[Time.now.strftime('%A')]
  @date = Time.now.strftime '%d.%m.%Y'
  @array_show_these_days = ARRAY_ALL_KNOWN_DAYS_OF_THE_WEEK # Which days to show. Should be an array.
  try_to_load_data
  # Store all the days in this hash.
  @all_days = {
    :mo => [], :di => [],
    :mi => [], :do => [],
    :fr => [], :sa => [],
    :so => []
  }
end

#runObject

#

run

#


588
589
590
591
592
593
594
595
596
597
# File 'lib/studium/utility_scripts/stundenplan.rb', line 588

def run # (run tag)
  process_dataset # This method will set @data.
  heute_ist
  unless @input.to_s.empty? # The user wants to display only a specific day.
    @array_show_these_days = [@input]
  end
  show_days
  show_legende
  my_cliner
end

#set_input(i = '') ⇒ Object

#

set_input

This method contains the commandline-information. We have to sanitize the input that a user can give to us.

#


132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/studium/utility_scripts/stundenplan.rb', line 132

def set_input(i = '')
  i = i.dup if i
  i = i.join ' ' if i.is_a? Array
  i = i.strip.chomp if i.is_a? String
  i = i.to_s.downcase
  if REVERSE_GERMAN_WEEK_NAMES.has_key?(i)
    i = REVERSE_GERMAN_WEEK_NAMES[i.capitalize].downcase.to_sym
  end
  case i # case tag
  when '1','monday','mo'
    i = :mo
  when '2','tuesday','tu','di'
    i = :di
  when '3','wednesday','mi','mit'
    i = :mi
  when '4','thursday','do'
    i = :do
  when '5','friday','fr'
    i = :fr
  when '6','saturday','sa'
    i = :sa
  when '7','sunday','so'
    i = :so
  when 'week'
    heute_ist
    cliner { WocheAnzeiger.new }
    exit
  # ======================================================================= #
  # === stundenplan --help
  # ======================================================================= #
  when 'HELP',/-?-?help/,'show_usage'
    show_usage(true)
  # ======================================================================= #
  # === stundenplan --excel
  # ======================================================================= #
  when 'SPREADSHEET','EXCEL','XLS','xls',/-?-?excel/
    silent_run
    create_spreadsheet
    exit
  # ======================================================================= #
  # === stundenplan --show_stats
  # ======================================================================= #
  when 'STATS','stats',/-?-?show(_|-)?stats/
    show_stats    
  # ======================================================================= #
  # === stundenplan --pdf
  # ======================================================================= #
  when 'PDF',/-?-?pdf/
    silent_run
    generate_pdf_file
    exit
  # ======================================================================= #
  # === stundenplan --dataset?
  # ======================================================================= #
  when /^-?-?dataset\??$/
    show_dataset
    exit
  # ======================================================================= #
  # === stundenplan display
  # ======================================================================= #
  when 'display','show'
    display_stundenplan_on_the_terminal
  when 'open_all','openall','edit'
    open_this_file_in_editor(false) # false for "don't exit yet."
    open_stundenplan_in_editor
  when 'open_self','openself'
    open_this_file_in_editor
  when 'open','openyaml','open_yaml'
    open_stundenplan_in_editor
  end
  @input = i
end

#show_datasetObject

#

show_dataset

#


580
581
582
583
# File 'lib/studium/utility_scripts/stundenplan.rb', line 580

def show_dataset
  opnn; e 'Now displaying the dataset:'
  pp @data
end

#show_daysObject

#

show_days

#


394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/studium/utility_scripts/stundenplan.rb', line 394

def show_days
  @all_days.each {|entry|
    if @array_show_these_days.include? entry[0]
      if entry[1].empty?
      else # Ok, is included, so we may display them.
        if @may_we_show_the_result
          my_cliner
          e green('Wochentag: ')+
            simp(GERMAN_WEEK_NAMES[entry[0].to_s.capitalize])+N+N
        end
        sorted = entry[1].sort_by {|data| data[1] }
        title_zeit_priority_ort_vorbesprechung(sorted)
      end
    else # Else not included so we won't show these entries.
    end
  }
end

#show_legendeObject

#

show_legende

#


477
478
479
480
481
# File 'lib/studium/utility_scripts/stundenplan.rb', line 477

def show_legende
  if @may_we_show_the_result
    e N+'    Legende: '+COLOUR_FOR_LEGENDE+'rot'+rev+' ist Priorität.'
  end
end

#show_statsObject

#

show_stats

To invoke this, do:

stupa show_stats
#


213
214
215
216
217
# File 'lib/studium/utility_scripts/stundenplan.rb', line 213

def show_stats
  n_entries = @data.keys.size
  e 'We found '+sfancy(n_entries)+' entries.'
  exit
end

#show_usage(shall_we_exit = false) ⇒ Object

#

show_usage (help tag)

#


115
116
117
118
119
120
121
122
123
124
# File 'lib/studium/utility_scripts/stundenplan.rb', line 115

def show_usage(shall_we_exit = false)
  if Object.const_defined? :ClassDocuShower
    ClassDocuShower.new __FILE__, :verbose => false
  end
  e
  opnn; e ' - You can also create spreadsheets by '\
          'passing the argument "xls".'
  opnn; e ' - You can also generate .pdf files by issuing "PDF".'
  exit if shall_we_exit
end

#silent_runObject

#

silent_run

#


527
528
529
530
# File 'lib/studium/utility_scripts/stundenplan.rb', line 527

def silent_run
  @may_we_show_the_result = false
  run
end

#title_zeit_priority_ort_vorbesprechung(i) ⇒ Object

#

title_zeit_priority_ort_vorbesprechung

This method will show the title, the zeit, the priority, the ort and the Vorbesprechung, which can be optional however.

#


449
450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/studium/utility_scripts/stundenplan.rb', line 449

def title_zeit_priority_ort_vorbesprechung(i)
  i.each {|title, zeit, priority, ort, vorbesprechung|
    zeit = zeit.force_encoding(::Studium.main_encoding?)
    ort  = ort.force_encoding(::Studium.main_encoding?)
    result = '  '+COLOUR_FOR_TITLE+title.to_s+rev+' ('+
             RED+priority+rev+'): '+zeit.to_s+', '+
             green(ort)
    if vorbesprechung
      result << N+PINK+'Vorbesprechung '+rev+
                'ist am: '+sfancy(vorbesprechung)
    end
    e result if @may_we_show_the_result
  }
end

#try_to_load_dataObject

#

try_to_load_data

This method will try to load the yaml dataset.

#


286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/studium/utility_scripts/stundenplan.rb', line 286

def try_to_load_data
  _ = MAIN_FILE
  if File.exist? _
    begin
      @data = YAML.load_file(MAIN_FILE)
    rescue ArgumentError => error
      opnn; e 'A syntax-error happened in our dataset, the yaml '+
              'file at `'+sfile(MAIN_FILE)+'`.'
      pp error
      opnn; e 'Please make sure that the yaml file is valid.'
      @data = {}
    end
  else
    opnn; e 'Can not load `'+sfile(_)+'` as it does not exist.'
  end
end