Class: Studium::UpcomingMandatoryPresenceCourses

Inherits:
Base
  • Object
show all
Defined in:
lib/studium/utility_scripts/upcoming_mandatory_presence_courses/run.rb,
lib/studium/utility_scripts/upcoming_mandatory_presence_courses/constants.rb,
lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb

Overview

Studium::UpcomingMandatoryPresenceCourses

Constant Summary collapse

NAMESPACE =
#

NAMESPACE

#
inspect
ONE_HOUR =
#

ONE_HOUR

3600 seconds are in one hour.

#
3600
N_DAYS_INTO_THE_FUTURE =
#

N_DAYS_INTO_THE_FUTURE

Here you can decide how many days into the future this class will “look” into.

#
40

Constants inherited from Base

Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW

Constants included from Colours

Colours::COLOURS

Instance Method Summary collapse

Methods inherited from Base

#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?

Methods included from Colours

#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow

Constructor Details

#initialize(commandline_arguments = ARGV, run_already = true) ⇒ UpcomingMandatoryPresenceCourses

#

initialize

#


32
33
34
35
36
37
38
39
40
41
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb', line 32

def initialize(
    commandline_arguments = ARGV,
    run_already           = true
  )
  reset
  set_commandline_arguments(
    commandline_arguments
  )
  run if run_already
end

Instance Method Details

#filter_for_the_proper_entriesObject

#

filter_for_the_proper_entries

#


75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb', line 75

def filter_for_the_proper_entries
  # ======================================================================= #
  # First, grab only those entries that are indeed "prüfungsimmanent"
  # and that have at the least one 'lva_dates' entry:
  # ======================================================================= #
  @dataset.select! {|name_of_the_lecture, inner_hash|
    type = inner_hash[:type]
    is_this_a_prüfungsimment_course?(type) and
    inner_hash.has_key?('lva_dates')
  }
  # ======================================================================= #
  # Next, we should sort these entries.
  # ======================================================================= #
  _ = []
  today = Time.now
  n_seconds_in_the_future = @threshold_value_n_days_into_the_future * 24 * ONE_HOUR
  future_day = today+n_seconds_in_the_future
  @dataset.each_pair {|name_of_the_lecture, inner_hash|
    lva_dates = inner_hash['lva_dates']
    if lva_dates.nil?
      e steelblue('No lva-dates found for ')+royalblue(name_of_the_lecture)
    end
    first_entry = lva_dates.first
    first_entry = Time.parse(first_entry)
    # ===================================================================== #
    # Next we will determine whether this lecture will be added
    # or not. We will compare this to the threshold value.
    # ===================================================================== #
    if (first_entry < future_day) and (first_entry > today)
      _ << [first_entry, { name_of_the_lecture => inner_hash } ]
    end
  }
  _.sort_by! {|array|
    array.first
  }
  @dataset = _
end
#

menu (menu tag)

#


154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb', line 154

def menu(i = @commandline_arguments)
  if i.is_a? Array
    i.each {|entry| menu(entry) }
  else
    case i
    # ===================================================================== #
    # === 30days or 60days
    # ===================================================================== #
    when /^-?-?(\d{1,2})days$/
      set_n_days_into_the_future($1.to_s.dup)
    end
  end
end

#n_days_into_the_future?Boolean

#

n_days_into_the_future?

#

Returns:

  • (Boolean)


68
69
70
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb', line 68

def n_days_into_the_future?
  @threshold_value_n_days_into_the_future
end

#report(i = @dataset) ⇒ Object

#

report (report tag)

#


123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb', line 123

def report(
    i = @dataset
  )
  report_how_many_dates_into_the_future_we_will_be_looking
  e
  e "#{rev}Upcoming mandatory courses:"
  e
  index = 0
  right_arrow = right_arrow?
  i.each {|date_entry, inner_hash| index += 1
    name_of_the_lecture = inner_hash.keys.first
    e orange(index.to_s)+
      royalblue(') ')+
      steelblue(name_of_the_lecture)
    e
    e mediumturquoise("     #{right_arrow} #{date_entry}")
    e
  }
  e
end

#report_how_many_dates_into_the_future_we_will_be_lookingObject

#

report_how_many_dates_into_the_future_we_will_be_looking

#


116
117
118
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb', line 116

def report_how_many_dates_into_the_future_we_will_be_looking
  e "#{rev}Looking #{sfancy(n_days_into_the_future?)} days into the future."
end

#resetObject

#

reset

#


46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb', line 46

def reset
  super()
  # ======================================================================= #
  # === @namespace
  # ======================================================================= #
  @namespace = NAMESPACE
  # ======================================================================= #
  # === @dataset
  # ======================================================================= #
  @dataset = return_all_lectures
  # ======================================================================= #
  # === @threshold_value_n_days_into_the_future
  #
  # This variable determines how many days into the future we will look
  # at.
  # ======================================================================= #
  @threshold_value_n_days_into_the_future = N_DAYS_INTO_THE_FUTURE
end

#right_arrow?Boolean

#

right_arrow?

#

Returns:

  • (Boolean)


147
148
149
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb', line 147

def right_arrow?
  Roebe.right_arrow
end

#runObject

#

run

#


14
15
16
17
18
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/run.rb', line 14

def run
  menu
  filter_for_the_proper_entries
  report
end

#set_n_days_into_the_future(i) ⇒ Object

#

set_n_days_into_the_future

#


171
172
173
# File 'lib/studium/utility_scripts/upcoming_mandatory_presence_courses/upcoming_mandatory_presence_courses.rb', line 171

def set_n_days_into_the_future(i)
  @threshold_value_n_days_into_the_future = i.to_i
end