Class: Studium::AttributeLecturesToUniversity
- Inherits:
-
Base
- Object
- Base
- Studium::AttributeLecturesToUniversity
show all
- Defined in:
- lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb
Overview
Studium::AttributeLecturesToUniversity
Constant Summary
collapse
- NAMESPACE =
inspect
- IGNORE_LEHRAMT_CURRICULA =
#
IGNORE_LEHRAMT_CURRICULA
#
true
- IGNORE_MASTER_CURRICULA =
#
IGNORE_MASTER_CURRICULA
#
true
- DISPLAY_THE_NAME_OF_THE_LECTURES =
#
DISPLAY_THE_NAME_OF_THE_LECTURES
#
false
Constants inherited
from Base
Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW
Constants included
from Colours
Colours::COLOURS
Class Method Summary
collapse
-
.[](i = '') ⇒ Object
# === Studium::AttributeLecturesToUniversity[] ========================================================================= #.
Instance Method Summary
collapse
Methods inherited from Base
#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colour_for_ects_points, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?
Methods included from Colours
#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow
Constructor Details
49
50
51
52
53
54
55
56
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 49
def initialize(
i = nil,
run_already = true
)
reset
set_input(i)
run if run_already
end
|
Class Method Details
.[](i = '') ⇒ Object
#
Studium::AttributeLecturesToUniversity[]
#
376
377
378
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 376
def self.[](i = '')
new(i)
end
|
Instance Method Details
#append_this_onto_the_main_dataset(i) ⇒ Object
#
append_this_onto_the_main_dataset
#
170
171
172
173
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 170
def append_this_onto_the_main_dataset(i)
@dataset << i
@dataset.flatten!
end
|
#check_for_an_existing_file(i = @input) ⇒ Object
#
check_for_an_existing_file
This method can be used to check for an existing file. If it exists we will read in the dataset.
#
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 237
def check_for_an_existing_file(
i = @input
)
if i.is_a? Array
i.each {|entry| check_for_an_existing_file(entry) }
else
if File.exist? i
dataset = remove_empty_strings(
(
(
remove_newlines(
readlines_with_proper_encoding(i)
)
)
)
).map {|entry| entry.squeeze(' ') }
append_this_onto_the_main_dataset(dataset)
end
end
end
|
#colourize_ects_points(i) ⇒ Object
#
colourize_ects_points
#
361
362
363
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 361
def colourize_ects_points(i)
olivedrab(i)
end
|
227
228
229
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 227
def input?
@input
end
|
#iterate_over_the_main_dataset ⇒ Object
#
iterate_over_the_main_dataset
#
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 269
def iterate_over_the_main_dataset
if @dataset
@dataset.each {|entry|
pointer = @dataset_from_the_file_lecture_information[entry]
if pointer.nil?
e swarn('A problem was encountered (nil value) '\
'for the entry ')+sfancy(entry)
pp @dataset
end
curricula = obtain(:curricula, pointer)
n_ects = obtain(:ects, pointer)
curricula.each {|this_curriculum|
@hash_storing_the_ects_per_university[this_curriculum] += n_ects
}
}
sorted = @hash_storing_the_ects_per_university.sort_by {|a, n_ects_points|
n_ects_points
}.reverse
report(sorted)
end
end
|
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 178
def (
i = @input
)
if i.is_a? Array
i.each {|entry|
(entry)
}
else
case i when /^-?-?help$/
show_help
exit
when /-?-?bachelor(-|_)?master(-|_)?ve(c|k)torx?$/i,
/^-?-?combined$/i
set_300_ects_points
@input = return_file_for_this_curriculum(i.to_s.delete('-').to_sym)
@ignore_master_curricula = false
@n_ljust = 102
when /-?-?bachelor(-|_)?ve(c|k)torx?$/i,
/^-?-?bachelor$/i
set_180_ects_points
@input = return_file_for_this_curriculum(i.to_s.delete('-').to_sym)
@ignore_master_curricula = true
@n_ljust = 82
when /-?-?master(-|_)?ve(c|k)torx?$/i,
/^-?-?master$/i
set_120_ects_points
@input = return_file_for_this_curriculum(i.to_s.delete('-').to_sym)
@ignore_master_curricula = false
@n_ljust = 82
end
end
end
|
#report(i) ⇒ Object
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 294
def report(i)
if i.is_a? Array
if IGNORE_LEHRAMT_CURRICULA or IGNORE_MASTER_CURRICULA
i.reject! {|a,b|
keep_or_reject = :keep
curriculum_name = curriculum_number_to_curriculum_name(a)
if curriculum_name.nil?
e "Unknown entry: #{crimson(a)}"
e 'This entry will be ignored.'
next
end
if IGNORE_LEHRAMT_CURRICULA
keep_or_reject = :reject if curriculum_name.include? 'Lehramt'
end
if @ignore_master_curricula
keep_or_reject = :reject if curriculum_name.include? 'Master'
end
if keep_or_reject == :reject
true
elsif keep_or_reject == :keep
false
end
} end
e
opnn; e 'The following universities are involved with the given lectures:'
e
i.each {|curriculum_number, n_ects_points|
percentage = n_ects_points * 100 / total_ects?
full_name_of_the_curriculum = curriculum_number_to_curriculum_name(curriculum_number)
percentage_value = percentage.round(1).to_s.rjust(4)
colourized_percentage_value = mediumseagreen(
" (#{percentage_value}%)"
)
which_university = from_curriculum_number_to_university(curriculum_number)
which_university = royalblue(" [#{which_university.to_s.center(13)}]")
e royalblue((full_name_of_the_curriculum.to_s+':').ljust(@n_ljust))+
colourize_ects_points(n_ects_points.to_s.rjust(5)+' ECTS')+
colourized_percentage_value+
which_university
if @display_the_name_of_the_lectures
selection = @dataset_from_the_file_lecture_information.select {|name_of_the_lecture, inner_hash|
curricula = obtain(:curricula, inner_hash)
curricula.include?(curriculum_number) and @dataset.include?(name_of_the_lecture)
}
selection.each_pair {|name_of_the_lecture, inner_hash|
n_ects_points = obtain(:n_ects_points, inner_hash)
e teal(' '+name_of_the_lecture.ljust(83)+
' ['+n_ects_points.to_s+' ECTS]')
}
end
}; e
end
end
|
#reset ⇒ Object
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 61
def reset
super()
@namespace = NAMESPACE
@dataset = [] @dataset_from_the_file_lecture_information = lecture_information
@hash_storing_the_ects_per_university = {}
@hash_storing_the_ects_per_university.default = 0
@ignore_master_curricula = IGNORE_MASTER_CURRICULA
@n_ljust = 66
@n_ects_points_in_total = 180 @display_the_name_of_the_lectures = DISPLAY_THE_NAME_OF_THE_LECTURES
end
|
#run ⇒ Object
368
369
370
371
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 368
def run
check_for_an_existing_file
iterate_over_the_main_dataset
end
|
#set_120_ects_points ⇒ Object
93
94
95
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 93
def set_120_ects_points
@n_ects_points_in_total = 120
end
|
#set_180_ects_points ⇒ Object
107
108
109
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 107
def set_180_ects_points
@n_ects_points_in_total = 180
end
|
#set_300_ects_points ⇒ Object
100
101
102
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 100
def set_300_ects_points
@n_ects_points_in_total = 300
end
|
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 114
def set_input(
i = ''
)
i = i.first if i.is_a? Array
i = i.to_s.dup
case i when ''
i = '--bachelor_vektor'
when 'file1'
i = Studium.return_this_file(:bvektor)
when 'file2'
i = studium_directory_at_home?+'TU_WIEN/yaml/'\
'master_individuelles_studium_nanobiotechnologische_informationssysteme.md'
end
if i.include? 'master_'
@ignore_master_curricula = false
end
@input = i
if @input.include? '--'
(@input)
end
end
|
#show_help ⇒ Object
#
show_help (help tag)
To invoke this help-menu, do:
attribute_lecture --help
For the available entry points, try:
attribute_lecture --bachelor
#
158
159
160
161
162
163
164
165
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 158
def show_help
opnn; e 'The following commandline-options are available for this class:'
e
e ' --bachelor # show the attributed lectures for the bachelor curriculum'
e ' --master # show the attributed lectures for the master curriculum'
e ' --combined # show the attributed lectures for both curricula combined'
e
end
|
#total_ects? ⇒ Boolean
86
87
88
|
# File 'lib/studium/utility_scripts/attribute_lectures_to_university/attribute_lectures_to_university.rb', line 86
def total_ects?
@n_ects_points_in_total
end
|