Class: Studium::Exams::LastExams
- Inherits:
-
Base
- Object
- Base
- Studium::Exams::LastExams
show all
- Defined in:
- lib/studium/exams/last_exams/last_exams.rb
Overview
Studium::Exams::LastExams
Constant Summary
collapse
- NAMESPACE =
inspect
- DEFAULT_N_LAST_EXAMS =
#
DEFAULT_N_LAST_EXAMS
Determine how many exams are to be shown by default, if no other arguments are passed to this class.
#
12
Constants inherited
from Base
Base::ARRAY_HTML_COLOURS_IN_USE, Base::CHECK_FOR_INCORRECT_ENTRIES_IN_THE_QUESTION_ANSWER_FILE_THAT_SHOULD_BE_COMMENTS, Base::COLOURS, Base::COMMON_YEAR_DAYS_IN_MONTH, Base::GRAY, Base::LEFT_PADDING, Base::N_CHARACTERS_PER_LINE, Base::UNICODE_RIGHT_ARROW
Constants included
from Colours
Colours::COLOURS
Class Method Summary
collapse
-
.[](i = '') ⇒ Object
# === Studium::Exams::LastExams[] ========================================================================= #.
Instance Method Summary
collapse
Methods inherited from Base
#add_proper_year_entry_to_this_line, #already_solved_this_lva_number?, #append_what_into, #available_topics_as_short_name, #average_grade, #bachelor_master_or_diploma, #base_dir?, #be_silent, #be_verbose?, #beautiful_url, #change_directory, #cheering_person, #cliner, #colourize_percentage, #commandline_arguments?, #commandline_arguments_joined, #commandline_arguments_with_hyphens?, #convert_this_array_of_lectures_into_the_full_dataset, #copy, #cpruby, #create_directory, #create_file, #csv_file?, #current_month?, #datum?, #day_month_year, #debug?, #delete_file, #directory_of_the_exam_topics?, #directory_to_my_exam_topics, #directory_to_the_exam_topics?, #disable_colours, #disable_colours_globally, #do_not_be_verbose, #do_not_use_opn, #do_these_curricula_include_both_a_bachelor_and_a_master_curriculum?, #does_this_line_include_a_german_weekday?, #does_this_line_include_a_html_colour?, #e, #ecomment, #editor?, #ee, #enable_colours, #enable_colours_globally, #enable_debug, #encoding?, #english_to_german_weekday, #ensure_main_encoding, #ensure_that_the_log_directory_exists, #eparse, #erev, #esystem, #etomato, #exit_program, #expand_topic, #extract_dd_mm_yyyy, #file_lecture_information?, #file_read_with_proper_encoding, #filter_away_invalid_questions, #find_corresponding_exam_topic, #first_argument?, #first_non_hyphen_argument?, #from_curriculum_id_to_university, #german_date_notation, #german_weekday?, #german_weekdays?, #has_a_bachelor_curriculum?, #has_a_master_curriculum?, #has_this_exam_topic_been_solved?, #has_year_entry?, #hh_mm_ss_dd_mm_yyyy, #horizontal_bar?, #html_log_directory?, #is_a_master_lecture?, #is_a_weekday?, #is_connected_to_the_www?, #is_on_roebe?, #is_prüfungsimmanent?, #is_this_a_valid_html_colour?, #is_this_day_today?, #konsole_support?, #last_file?, #lectures_from_indi1, #lectures_from_indi2, #lectures_from_indi3, #lectures_from_indi4, #lectures_from_the_bachelor_genetik_curriculum, #lectures_from_the_individual_vektor_curricula, #load_yaml_dataset, #move_file, #n_days_difference_from_today_to_this_day, #no_ext_name, #no_file_at, #number_to_month, #obtain, #obtain_lectures_from_this_curriculum, #open_in_editor, #opnn, #path_to_exam_topic?, #read_dataset_from_a_curriculum_file, #read_in_exam_dataset_from_this_file, #read_this_file_with_default_encoding, #readlines_from_this_input_file, #register_sigint, #remove_empty_strings, #remove_escape_sequences, #remove_internal_comments, #remove_leading_comments, #remove_leading_weekday_names_from, #remove_newlines, #remove_tags_from_this_input, #rename_kde_konsole_tab, #rename_konsole_tab?, #replace_all_html_colours_in_this, #replace_bold_token_with_default_colour, #replace_italic_token_with_default_colour, #replace_italic_token_with_this_colour, #replace_regular_numbers_with_unicode_numbers, #replace_underline_token_with_default_colour, #replace_underline_token_with_this_colour, #return_all_bachelor_lectures, #return_all_exams_on_this_day, #return_all_numbers_from, #return_all_registered_curricula, #return_all_steop_lectures, #return_current_year, #return_dataset_for_this_topic, #return_dataset_from_this_curriculum_file, #return_dd_mm_yy_and_time_from, #return_directory_for, #return_ects_points_from_these_lectures, #return_either_grey_or_the_custom_colour_for_answers, #return_either_grey_or_the_custom_colour_for_questions, #return_file_for_this_curriculum, #return_german_name_for_this_english_month, #return_german_weekday_of?, #return_hh_mm_ss_from, #return_hour_from_this, #return_lectures_from_bachelor_vektor_curriculum, #return_lectures_with_at_the_least_one_upcoming_exam, #return_local_path_of_this_pwdstud, #return_lva_number_of_this_lecture, #return_month_fitting_to_this_input, #return_n_days_until_monday, #return_n_days_until_sunday, #return_n_exam_questions_in, #return_n_questions_were_answered_for_this_topic, #return_name_of_the_weekday, #return_name_of_this_curriculum, #return_name_of_this_curriculum_based_on_its_id_number, #return_opnn, #return_passed_courses, #return_pwd, #return_random_curriculum, #return_sanitized_dataset_from_the_file_lecture_information, #return_solved_lectures, #return_steop_lectures, #return_the_remote_homepage_url, #return_this_line_has_n_characters_as_html_colour_tags, #return_title_from_this_curriculum_file, #rev, #right_arrow?, #rinstall2, #roebe_exam_directory?, #ruby_src_dir_at_home?, #runmode?, #sanitize_this_topic, #sanitize_url, #select_lectures_with_this_key, #set_be_quiet, #set_be_verbose, #set_commandline_arguments, #set_commandline_mode, #set_runmode, #set_this_cd_alias_to, #set_www_mode, #sfancy, #shall_we_make_use_of_unicode_symbols?, #show_todays_date, #simp, #sort_these_lecture_names_by_time, #spacer, #swarn, #this_month_has_n_days?, #total_ects_points_passed, #translate_dd_mm_yyyy_to_weekday, #try_to_require_the_rcfiles, #turn_this_array_into_the_full_dataset, #unicode_blocks_line, #use_colours?, #use_opn?, #vertical_bar?, #web_liner, #weekday?, #weekdays?, #word_wrap, #write_what_into, #www_connection_is_unavailable, #www_mode?, #yaml_dir?
Methods included from Colours
#bold_blue, #bold_red, #bold_yellow, #cadetblue, #chartreuse, crimson, #darkgray, darkgreen, darkseagreen, deepskyblue, #deepskyblue, default_colour, #dimgray, disable_colours, #dodgerblue, e, #efancy, enable_colours, #ewarn, #forestgreen, gold, #grey, lightblue, lightgreen, #lightslategray, #lightsteelblue, #mediumorchid, #mediumseagreen, #oldlace, #olivedrab, orange, orangered, #orchid, palevioletred, #papayawhip, rev, royalblue, sdir, #sdir, sfancy, #sfancy, sfile, #sfile, simp, #simp, slateblue, steelblue, #steelblue, #swarn, swarn, #teal, turquoise, use_colours?, use_this_colour_for_exam_answers, use_this_colour_for_exam_questions, #yellow
Constructor Details
#initialize(i = nil, run_already = true) ⇒ LastExams
47
48
49
50
51
52
53
54
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 47
def initialize(
i = nil,
run_already = true
)
reset
set_input(i)
run if run_already
end
|
Class Method Details
.[](i = '') ⇒ Object
#
Studium::Exams::LastExams[]
#
360
361
362
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 360
def self.[](i = '')
new(i)
end
|
Instance Method Details
#col1(i) ⇒ Object
306
307
308
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 306
def col1(i)
mediumaquamarine(i)
end
|
#col2(i) ⇒ Object
299
300
301
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 299
def col2(i)
sfancy(i)
end
|
#colour_for_ects_points(i) ⇒ Object
#
colour_for_ects_points
#
218
219
220
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 218
def colour_for_ects_points(i)
lightcoral(i)
end
|
171
172
173
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 171
def input?
@input
end
|
#n_lectures? ⇒ Boolean
197
198
199
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 197
def n_lectures?
@n_lectures
end
|
#obtain_dataset(i = FILE_PASSED_EXAMS_PER_MONTH) ⇒ Object
#
obtain_dataset
This method will obtain the dataset but also do some sanitizing.
#
227
228
229
230
231
232
233
234
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 227
def obtain_dataset(
i = FILE_PASSED_EXAMS_PER_MONTH
)
_ = readlines_from_this_input_file(i).select {|line|
line =~ /^\d+/ }
@dataset = _
end
|
#report_match ⇒ Object
178
179
180
181
182
183
184
185
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 178
def report_match
_ = @dataset[0.. (input? - 1)]
set_n_lectures(_.size)
report_this_dataset(_)
end
|
#report_summary ⇒ Object
204
205
206
207
208
209
210
211
212
213
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 204
def report_summary
e
e rosybrown(
' n ECTS in total: '.ljust(101)
)+
colour_for_ects_points(
@total_n_ects.to_s+' ECTS points'
)+
' (among '+n_lectures?.to_s+' lectures)'
end
|
#report_this_dataset(i) ⇒ Object
Also known as:
report
#
report_this_dataset (report tag)
#
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 253
def report_this_dataset(i)
left_just = 84
e
i.each_with_index {|line, index|
index += 1
if line.is_a? Array
splitted = line
else
splitted = line.split('|').map(&:strip)
end
name_of_the_lecture = splitted.last
date = splitted.first
n_ects_points = splitted[2].to_f @total_n_ects += n_ects_points
grade_of_the_passed_exam = splitted[3].to_s
which_university = splitted[4].to_s.strip
colourized_and_padded_which_university =
royalblue(which_university.center(7))
colourized_note = olivedrab("Note: #{grade_of_the_passed_exam}")
e "#{col1(index.to_s.rjust(4))}"\
") #{col2(name_of_the_lecture.ljust(left_just))} "\
"#{orangered(date)} "\
"#{colour_for_ects_points(n_ects_points.to_s.rjust(4)+' ECTS points')} "\
"#{colourized_and_padded_which_university} "\
"#{colourized_note}"
}
report_summary
e
end
|
#report_this_hash(i) ⇒ Object
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 328
def report_this_hash(i)
sum_of_ects = 0
index = 0
e
i.each_pair {|name_of_the_lecture, inner_hash| index += 1
n_ects = obtain(:ects, inner_hash)
solved_at = obtain(:solved_at, inner_hash)
remote_url = obtain(:remote_url, inner_hash)
sum_of_ects += n_ects
e rev+
col1(
index.to_s.rjust(3)+')'
)+' '+
col2(name_of_the_lecture.strip.ljust(84))+' '+
colourize_ects(n_ects.to_s.rjust(4)+' ECTS')+' '+
slateblue('Bestanden am: '+solved_at.to_s)
e (' ' * 5)+olivedrab('→ '+remote_url)
}
e (' ' * 89)+colourize_ects(sum_of_ects.to_s+' ECTS')
e
end
|
#reset ⇒ Object
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 59
def reset
super()
@namespace = NAMESPACE
@total_n_ects = 0
@n_lectures = 0
obtain_dataset end
|
#return_all_passed_exams_belonging_to_this_curriculum(i = '033630') ⇒ Object
#
return_all_passed_exams_belonging_to_this_curriculum
#
313
314
315
316
317
318
319
320
321
322
323
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 313
def return_all_passed_exams_belonging_to_this_curriculum(
i = '033630'
)
i = i.to_s
passed_courses = return_passed_courses
selection = passed_courses.select {|key, hash|
hash.has_key?('curricula') and
hash['curricula'].include? i
}
return selection
end
|
#run ⇒ Object
353
354
355
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 353
def run
report_match
end
|
#
Invocation examples:
last_exams --12
last_exams --15
#
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 85
def set_input(
i = DEFAULT_N_LAST_EXAMS
)
i = i.first if i.is_a? Array
i = DEFAULT_N_LAST_EXAMS if i.nil?
case i when /^-?-?for(-|_)?this(-|_)?curriculum=(.+)$/i this_curriculum = $3.to_s.dup
report_this_hash(
return_all_passed_exams_belonging_to_this_curriculum(this_curriculum)
)
exit
when /^-?-?grade=(.+)/
seek_this_grade = $1.to_s.to_i
dataset = @dataset.map {|inner_entry|
inner_entry.split('|').map(&:strip)
}
dataset_mapped_to_the_grade = dataset.select {|inner_array|
grade = inner_array[3].to_i
grade == seek_this_grade
}
@dataset = i = dataset_mapped_to_the_grade
when :show_all_passed_exams
dataset_from_the_file = File.readlines(FILE_PASSED_EXAMS_PER_MONTH)
dataset = dataset_from_the_file.select! {|line|
line =~ /^d+/ }
i = dataset.size
when /-?-?uni-?wien/i
_ = @dataset.select {|line| line.include? '| UniWien |' }
report_this_dataset(_)
exit
when /-?-?vetmed/i
_ = @dataset.select {|line| line.include? '| Vetmed |' }
report_this_dataset(_)
exit
when /-?-?file\??/
show_main_file_in_use
exit
when /-?-?help/
show_help
exit
end
i = i.to_s.delete('-')
i = i.to_i @input = i
end
|
#set_n_lectures(i) ⇒ Object
190
191
192
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 190
def set_n_lectures(i)
@n_lectures = i
end
|
#show_help ⇒ Object
239
240
241
242
243
244
245
246
247
248
|
# File 'lib/studium/exams/last_exams/last_exams.rb', line 239
def show_help
opnn; e 'These options are available for the class:'
e
eparse ' --file? # show which file we will use as our dataset'
eparse ' --grade=1 # show only exams that were passed with a '\
'certain grade'
eparse ' --for-this-curriculum=033630 # show only '\
'passed exams belonging to this curriculum'
e
end
|
#show_main_file_in_use ⇒ Object
#
show_main_file_in_use
Invocation example:
last_exams --file?
#